Class: AlogramPayRisk::Account

Inherits:
ApiModelBase show all
Defined in:
lib/alogram_payrisk/models/account.rb

Overview

The application-layer Account object.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Account

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/alogram_payrisk/models/account.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::Account` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::Account`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'device_info')
    self.device_info = attributes[:'device_info']
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end
end

Instance Attribute Details

#device_infoObject

Returns the value of attribute device_info.



19
20
21
# File 'lib/alogram_payrisk/models/account.rb', line 19

def device_info
  @device_info
end

#emailObject

Email address of the customer.



28
29
30
# File 'lib/alogram_payrisk/models/account.rb', line 28

def email
  @email
end

#metadataObject

Optional key-value pairs providing additional context for the request. Each key should be descriptive, and values should not exceed 2048 characters. Each key should be descriptive.



31
32
33
# File 'lib/alogram_payrisk/models/account.rb', line 31

def 
  @metadata
end

#phoneObject

Phone number that supports international E.164 format, as well as spaces, dashes, and parentheses. Examples: "+1 (415) 555-2671", "415-555-2671", "+14155552671"



25
26
27
# File 'lib/alogram_payrisk/models/account.rb', line 25

def phone
  @phone
end

#timestampObject

RFC 3339 timestamp with timezone.



22
23
24
# File 'lib/alogram_payrisk/models/account.rb', line 22

def timestamp
  @timestamp
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/alogram_payrisk/models/account.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/alogram_payrisk/models/account.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/alogram_payrisk/models/account.rb', line 34

def self.attribute_map
  {
    :'device_info' => :'deviceInfo',
    :'timestamp' => :'timestamp',
    :'phone' => :'phone',
    :'email' => :'email',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/alogram_payrisk/models/account.rb', line 239

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/alogram_payrisk/models/account.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/alogram_payrisk/models/account.rb', line 55

def self.openapi_types
  {
    :'device_info' => :'DeviceInfo',
    :'timestamp' => :'String',
    :'phone' => :'String',
    :'email' => :'String',
    :'metadata' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



214
215
216
217
218
219
220
221
222
# File 'lib/alogram_payrisk/models/account.rb', line 214

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      device_info == o.device_info &&
      timestamp == o.timestamp &&
      phone == o.phone &&
      email == o.email &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


226
227
228
# File 'lib/alogram_payrisk/models/account.rb', line 226

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



232
233
234
# File 'lib/alogram_payrisk/models/account.rb', line 232

def hash
  [device_info, timestamp, phone, email, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/alogram_payrisk/models/account.rb', line 110

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(\.\d{1,9})?(Z|[+-]\d{2}:\d{2})$/)
  if !@timestamp.nil? && @timestamp !~ pattern
    invalid_properties.push("invalid value for \"timestamp\", must conform to the pattern #{pattern}.")
  end

  if !@phone.nil? && @phone.to_s.length > 30
    invalid_properties.push('invalid value for "phone", the character length must be smaller than or equal to 30.')
  end

  if !@phone.nil? && @phone.to_s.length < 7
    invalid_properties.push('invalid value for "phone", the character length must be greater than or equal to 7.')
  end

  if !@email.nil? && @email.to_s.length > 320
    invalid_properties.push('invalid value for "email", the character length must be smaller than or equal to 320.')
  end

  if !@email.nil? && @email.to_s.length < 3
    invalid_properties.push('invalid value for "email", the character length must be greater than or equal to 3.')
  end

  if !@metadata.nil? && @metadata.to_s.length > 2048
    invalid_properties.push('invalid value for "metadata", the character length must be smaller than or equal to 2048.')
  end

  if !@metadata.nil? && @metadata.to_s.length < 1
    invalid_properties.push('invalid value for "metadata", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/alogram_payrisk/models/account.rb', line 261

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
150
151
152
153
154
155
156
157
# File 'lib/alogram_payrisk/models/account.rb', line 147

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@timestamp.nil? && @timestamp !~ Regexp.new(/^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(\.\d{1,9})?(Z|[+-]\d{2}:\d{2})$/)
  return false if !@phone.nil? && @phone.to_s.length > 30
  return false if !@phone.nil? && @phone.to_s.length < 7
  return false if !@email.nil? && @email.to_s.length > 320
  return false if !@email.nil? && @email.to_s.length < 3
  return false if !@metadata.nil? && @metadata.to_s.length > 2048
  return false if !@metadata.nil? && @metadata.to_s.length < 1
  true
end