Class: AlogramPayRisk::AuthContext

Inherits:
ApiModelBase show all
Defined in:
lib/alogram_payrisk/models/auth_context.rb

Overview

Contextual identity information from the authentication layer.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AuthContext

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/alogram_payrisk/models/auth_context.rb', line 59

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::AuthContext` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::AuthContext`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'uid')
    self.uid = attributes[:'uid']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end
end

Instance Attribute Details

#providerObject

The identity provider type (e.g., "external", "oidc", "saml").



23
24
25
# File 'lib/alogram_payrisk/models/auth_context.rb', line 23

def provider
  @provider
end

#uidObject

Unique identifier for an authenticated principal (e.g., an identity provider UID or Subject). Unprefixed and case-sensitive. Supports common OIDC characters like ":", "|", "@", and ".".



20
21
22
# File 'lib/alogram_payrisk/models/auth_context.rb', line 20

def uid
  @uid
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



34
35
36
# File 'lib/alogram_payrisk/models/auth_context.rb', line 34

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/alogram_payrisk/models/auth_context.rb', line 39

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
# File 'lib/alogram_payrisk/models/auth_context.rb', line 26

def self.attribute_map
  {
    :'uid' => :'uid',
    :'provider' => :'provider'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/alogram_payrisk/models/auth_context.rb', line 156

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



52
53
54
55
# File 'lib/alogram_payrisk/models/auth_context.rb', line 52

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



44
45
46
47
48
49
# File 'lib/alogram_payrisk/models/auth_context.rb', line 44

def self.openapi_types
  {
    :'uid' => :'String',
    :'provider' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



134
135
136
137
138
139
# File 'lib/alogram_payrisk/models/auth_context.rb', line 134

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      uid == o.uid &&
      provider == o.provider
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


143
144
145
# File 'lib/alogram_payrisk/models/auth_context.rb', line 143

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



149
150
151
# File 'lib/alogram_payrisk/models/auth_context.rb', line 149

def hash
  [uid, provider].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/alogram_payrisk/models/auth_context.rb', line 84

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@uid.nil? && @uid.to_s.length > 128
    invalid_properties.push('invalid value for "uid", the character length must be smaller than or equal to 128.')
  end

  if !@uid.nil? && @uid.to_s.length < 10
    invalid_properties.push('invalid value for "uid", the character length must be greater than or equal to 10.')
  end

  pattern = Regexp.new(/^[a-zA-Z0-9\-_:|@.]{10,128}$/)
  if !@uid.nil? && @uid !~ pattern
    invalid_properties.push("invalid value for \"uid\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/alogram_payrisk/models/auth_context.rb', line 178

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



105
106
107
108
109
110
111
# File 'lib/alogram_payrisk/models/auth_context.rb', line 105

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@uid.nil? && @uid.to_s.length > 128
  return false if !@uid.nil? && @uid.to_s.length < 10
  return false if !@uid.nil? && @uid !~ Regexp.new(/^[a-zA-Z0-9\-_:|@.]{10,128}$/)
  true
end