Class: AlogramPayRisk::CategorySignal

Inherits:
ApiModelBase show all
Defined in:
lib/alogram_payrisk/models/category_signal.rb

Overview

Risk analysis for a specific business category.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CategorySignal

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/alogram_payrisk/models/category_signal.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::CategorySignal` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::CategorySignal`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'level')
    self.level = attributes[:'level']
  else
    self.level = nil
  end

  if attributes.key?(:'score')
    self.score = attributes[:'score']
  end

  if attributes.key?(:'reasons')
    if (value = attributes[:'reasons']).is_a?(Array)
      self.reasons = value
    end
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end
end

Instance Attribute Details

#levelObject

Returns the value of attribute level.



19
20
21
# File 'lib/alogram_payrisk/models/category_signal.rb', line 19

def level
  @level
end

#metadataObject

Derived evidence and enrichment data for this category.



28
29
30
# File 'lib/alogram_payrisk/models/category_signal.rb', line 28

def 
  @metadata
end

#reasonsObject

Specific reason codes for this category.



25
26
27
# File 'lib/alogram_payrisk/models/category_signal.rb', line 25

def reasons
  @reasons
end

#scoreObject

Category-specific risk score (0.00 - 1.00).



22
23
24
# File 'lib/alogram_payrisk/models/category_signal.rb', line 22

def score
  @score
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/alogram_payrisk/models/category_signal.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/alogram_payrisk/models/category_signal.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
# File 'lib/alogram_payrisk/models/category_signal.rb', line 53

def self.attribute_map
  {
    :'level' => :'level',
    :'score' => :'score',
    :'reasons' => :'reasons',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/alogram_payrisk/models/category_signal.rb', line 209

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
# File 'lib/alogram_payrisk/models/category_signal.rb', line 83

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
# File 'lib/alogram_payrisk/models/category_signal.rb', line 73

def self.openapi_types
  {
    :'level' => :'RiskLevelEnum',
    :'score' => :'Float',
    :'reasons' => :'Array<String>',
    :'metadata' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



185
186
187
188
189
190
191
192
# File 'lib/alogram_payrisk/models/category_signal.rb', line 185

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      level == o.level &&
      score == o.score &&
      reasons == o.reasons &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


196
197
198
# File 'lib/alogram_payrisk/models/category_signal.rb', line 196

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



202
203
204
# File 'lib/alogram_payrisk/models/category_signal.rb', line 202

def hash
  [level, score, reasons, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/alogram_payrisk/models/category_signal.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @level.nil?
    invalid_properties.push('invalid value for "level", level cannot be nil.')
  end

  if !@score.nil? && @score > 1.0
    invalid_properties.push('invalid value for "score", must be smaller than or equal to 1.0.')
  end

  if !@score.nil? && @score < 0.0
    invalid_properties.push('invalid value for "score", must be greater than or equal to 0.0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/alogram_payrisk/models/category_signal.rb', line 231

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
150
151
152
153
# File 'lib/alogram_payrisk/models/category_signal.rb', line 147

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @level.nil?
  return false if !@score.nil? && @score > 1.0
  return false if !@score.nil? && @score < 0.0
  true
end