Class: AlogramPayRisk::DecisionResolutionRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/alogram_payrisk/models/decision_resolution_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DecisionResolutionRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::DecisionResolutionRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::DecisionResolutionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'target_type')
    self.target_type = attributes[:'target_type']
  else
    self.target_type = nil
  end

  if attributes.key?(:'target_id')
    self.target_id = attributes[:'target_id']
  else
    self.target_id = nil
  end

  if attributes.key?(:'decision')
    self.decision = attributes[:'decision']
  else
    self.decision = nil
  end

  if attributes.key?(:'analyst')
    self.analyst = attributes[:'analyst']
  else
    self.analyst = nil
  end

  if attributes.key?(:'resolution_reason')
    self.resolution_reason = attributes[:'resolution_reason']
  else
    self.resolution_reason = nil
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end
end

Instance Attribute Details

#analystObject

Returns the value of attribute analyst.



27
28
29
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 27

def analyst
  @analyst
end

#decisionObject

The resolution action to apply to the target.



25
26
27
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 25

def decision
  @decision
end

#notesObject

Additional operational notes or reasoning for this resolution.



33
34
35
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 33

def notes
  @notes
end

#resolution_reasonObject

The ML-feedback ground-truth reason classification.



30
31
32
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 30

def resolution_reason
  @resolution_reason
end

#target_idObject

The unique identifier of the target entity under review (e.g. pi_*).



22
23
24
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 22

def target_id
  @target_id
end

#target_typeObject

The business entity type being resolved.



19
20
21
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 19

def target_type
  @target_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 58

def self.attribute_map
  {
    :'target_type' => :'targetType',
    :'target_id' => :'targetId',
    :'decision' => :'decision',
    :'analyst' => :'analyst',
    :'resolution_reason' => :'resolutionReason',
    :'notes' => :'notes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 272

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 80

def self.openapi_types
  {
    :'target_type' => :'String',
    :'target_id' => :'String',
    :'decision' => :'String',
    :'analyst' => :'DecisionResolutionRequestAnalyst',
    :'resolution_reason' => :'String',
    :'notes' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



246
247
248
249
250
251
252
253
254
255
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 246

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      target_type == o.target_type &&
      target_id == o.target_id &&
      decision == o.decision &&
      analyst == o.analyst &&
      resolution_reason == o.resolution_reason &&
      notes == o.notes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


259
260
261
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 259

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



265
266
267
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 265

def hash
  [target_type, target_id, decision, analyst, resolution_reason, notes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 150

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @target_type.nil?
    invalid_properties.push('invalid value for "target_type", target_type cannot be nil.')
  end

  if @target_id.nil?
    invalid_properties.push('invalid value for "target_id", target_id cannot be nil.')
  end

  if @decision.nil?
    invalid_properties.push('invalid value for "decision", decision cannot be nil.')
  end

  if @analyst.nil?
    invalid_properties.push('invalid value for "analyst", analyst cannot be nil.')
  end

  if @resolution_reason.nil?
    invalid_properties.push('invalid value for "resolution_reason", resolution_reason cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 294

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/alogram_payrisk/models/decision_resolution_request.rb', line 178

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @target_type.nil?
  target_type_validator = EnumAttributeValidator.new('String', ["payment_intent", "account_event", "agent_delegation"])
  return false unless target_type_validator.valid?(@target_type)
  return false if @target_id.nil?
  return false if @decision.nil?
  decision_validator = EnumAttributeValidator.new('String', ["approve", "block", "challenge", "escalate"])
  return false unless decision_validator.valid?(@decision)
  return false if @analyst.nil?
  return false if @resolution_reason.nil?
  resolution_reason_validator = EnumAttributeValidator.new('String', ["legit_human", "legit_agent_authorized", "unauthorized_agent", "card_testing", "account_takeover", "friendly_fraud"])
  return false unless resolution_reason_validator.valid?(@resolution_reason)
  true
end