Class: AlogramPayRisk::DecisionResponse

Inherits:
ApiModelBase show all
Defined in:
lib/alogram_payrisk/models/decision_response.rb

Overview

The synchronous risk decision for a purchase.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DecisionResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/alogram_payrisk/models/decision_response.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::DecisionResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::DecisionResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'decision')
    self.decision = attributes[:'decision']
  else
    self.decision = nil
  end

  if attributes.key?(:'decision_at')
    self.decision_at = attributes[:'decision_at']
  else
    self.decision_at = nil
  end

  if attributes.key?(:'risk_score')
    self.risk_score = attributes[:'risk_score']
  else
    self.risk_score = nil
  end

  if attributes.key?(:'reasons')
    if (value = attributes[:'reasons']).is_a?(Array)
      self.reasons = value
    end
  end

  if attributes.key?(:'breakdown')
    self.breakdown = attributes[:'breakdown']
  end

  if attributes.key?(:'policy')
    self.policy = attributes[:'policy']
  end
end

Instance Attribute Details

#breakdownObject

Returns the value of attribute breakdown.



34
35
36
# File 'lib/alogram_payrisk/models/decision_response.rb', line 34

def breakdown
  @breakdown
end

#decisionObject

The authoritative, absolute policy command for this transaction. Downstream systems must bind their operational behavior (approve/decline/review) directly to this field.



23
24
25
# File 'lib/alogram_payrisk/models/decision_response.rb', line 23

def decision
  @decision
end

#decision_atObject

RFC 3339 timestamp with timezone.



26
27
28
# File 'lib/alogram_payrisk/models/decision_response.rb', line 26

def decision_at
  @decision_at
end

#idObject

Alogram’s unique, authoritative evaluation and transaction identifier. Prefixed with ‘pi_’ for purchases.



20
21
22
# File 'lib/alogram_payrisk/models/decision_response.rb', line 20

def id
  @id
end

#policyObject

Returns the value of attribute policy.



36
37
38
# File 'lib/alogram_payrisk/models/decision_response.rb', line 36

def policy
  @policy
end

#reasonsObject

Structured reason details for the decision.



32
33
34
# File 'lib/alogram_payrisk/models/decision_response.rb', line 32

def reasons
  @reasons
end

#risk_scoreObject

The authoritative, policy-adjusted blended risk score (0.0 - 1.0) derived from expert fusion.



29
30
31
# File 'lib/alogram_payrisk/models/decision_response.rb', line 29

def risk_score
  @risk_score
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/alogram_payrisk/models/decision_response.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/alogram_payrisk/models/decision_response.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/alogram_payrisk/models/decision_response.rb', line 61

def self.attribute_map
  {
    :'id' => :'id',
    :'decision' => :'decision',
    :'decision_at' => :'decisionAt',
    :'risk_score' => :'riskScore',
    :'reasons' => :'reasons',
    :'breakdown' => :'breakdown',
    :'policy' => :'policy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/alogram_payrisk/models/decision_response.rb', line 290

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/alogram_payrisk/models/decision_response.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
# File 'lib/alogram_payrisk/models/decision_response.rb', line 84

def self.openapi_types
  {
    :'id' => :'String',
    :'decision' => :'String',
    :'decision_at' => :'String',
    :'risk_score' => :'Float',
    :'reasons' => :'Array<ReasonDetail>',
    :'breakdown' => :'RiskBreakdown',
    :'policy' => :'DecisionResponsePolicy'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



263
264
265
266
267
268
269
270
271
272
273
# File 'lib/alogram_payrisk/models/decision_response.rb', line 263

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      decision == o.decision &&
      decision_at == o.decision_at &&
      risk_score == o.risk_score &&
      reasons == o.reasons &&
      breakdown == o.breakdown &&
      policy == o.policy
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


277
278
279
# File 'lib/alogram_payrisk/models/decision_response.rb', line 277

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



283
284
285
# File 'lib/alogram_payrisk/models/decision_response.rb', line 283

def hash
  [id, decision, decision_at, risk_score, reasons, breakdown, policy].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/alogram_payrisk/models/decision_response.rb', line 159

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @decision.nil?
    invalid_properties.push('invalid value for "decision", decision cannot be nil.')
  end

  if @decision_at.nil?
    invalid_properties.push('invalid value for "decision_at", decision_at cannot be nil.')
  end

  pattern = Regexp.new(/^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(\.\d{1,9})?(Z|[+-]\d{2}:\d{2})$/)
  if @decision_at !~ pattern
    invalid_properties.push("invalid value for \"decision_at\", must conform to the pattern #{pattern}.")
  end

  if @risk_score.nil?
    invalid_properties.push('invalid value for "risk_score", risk_score cannot be nil.')
  end

  if @risk_score > 1.0
    invalid_properties.push('invalid value for "risk_score", must be smaller than or equal to 1.0.')
  end

  if @risk_score < 0.0
    invalid_properties.push('invalid value for "risk_score", must be greater than or equal to 0.0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/alogram_payrisk/models/decision_response.rb', line 312

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/alogram_payrisk/models/decision_response.rb', line 196

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @decision.nil?
  decision_validator = EnumAttributeValidator.new('String', ["approve", "review", "decline", "step_up"])
  return false unless decision_validator.valid?(@decision)
  return false if @decision_at.nil?
  return false if @decision_at !~ Regexp.new(/^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(\.\d{1,9})?(Z|[+-]\d{2}:\d{2})$/)
  return false if @risk_score.nil?
  return false if @risk_score > 1.0
  return false if @risk_score < 0.0
  true
end