Class: AlogramPayRisk::DeviceInfo

Inherits:
ApiModelBase show all
Defined in:
lib/alogram_payrisk/models/device_info.rb

Overview

Aggregated device fingerprinting and behavioral patterns used for fraud detection.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DeviceInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/alogram_payrisk/models/device_info.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::DeviceInfo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::DeviceInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'fingerprint')
    self.fingerprint = attributes[:'fingerprint']
  end

  if attributes.key?(:'user_agent')
    self.user_agent = attributes[:'user_agent']
  end

  if attributes.key?(:'ip')
    self.ip = attributes[:'ip']
  end

  if attributes.key?(:'integrity')
    self.integrity = attributes[:'integrity']
  end
end

Instance Attribute Details

#fingerprintObject

Unique hash representing the device’s fingerprint. Lowercase hex. Prefix "fp_".



20
21
22
# File 'lib/alogram_payrisk/models/device_info.rb', line 20

def fingerprint
  @fingerprint
end

#integrityObject

Returns the value of attribute integrity.



27
28
29
# File 'lib/alogram_payrisk/models/device_info.rb', line 27

def integrity
  @integrity
end

#ipObject

Returns the value of attribute ip.



25
26
27
# File 'lib/alogram_payrisk/models/device_info.rb', line 25

def ip
  @ip
end

#user_agentObject

Browser’s User-Agent string, useful for identifying OS and browser type. Must be between 10 and 512 printable ASCII characters.



23
24
25
# File 'lib/alogram_payrisk/models/device_info.rb', line 23

def user_agent
  @user_agent
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/alogram_payrisk/models/device_info.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/alogram_payrisk/models/device_info.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
# File 'lib/alogram_payrisk/models/device_info.rb', line 30

def self.attribute_map
  {
    :'fingerprint' => :'fingerprint',
    :'user_agent' => :'userAgent',
    :'ip' => :'ip',
    :'integrity' => :'integrity'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/alogram_payrisk/models/device_info.rb', line 217

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
# File 'lib/alogram_payrisk/models/device_info.rb', line 60

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
# File 'lib/alogram_payrisk/models/device_info.rb', line 50

def self.openapi_types
  {
    :'fingerprint' => :'String',
    :'user_agent' => :'String',
    :'ip' => :'IpInfo',
    :'integrity' => :'Integrity'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



193
194
195
196
197
198
199
200
# File 'lib/alogram_payrisk/models/device_info.rb', line 193

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      fingerprint == o.fingerprint &&
      user_agent == o.user_agent &&
      ip == o.ip &&
      integrity == o.integrity
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


204
205
206
# File 'lib/alogram_payrisk/models/device_info.rb', line 204

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



210
211
212
# File 'lib/alogram_payrisk/models/device_info.rb', line 210

def hash
  [fingerprint, user_agent, ip, integrity].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/alogram_payrisk/models/device_info.rb', line 100

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@fingerprint.nil? && @fingerprint.to_s.length > 67
    invalid_properties.push('invalid value for "fingerprint", the character length must be smaller than or equal to 67.')
  end

  if !@fingerprint.nil? && @fingerprint.to_s.length < 35
    invalid_properties.push('invalid value for "fingerprint", the character length must be greater than or equal to 35.')
  end

  pattern = Regexp.new(/^fp_[a-f0-9]{32,64}$/)
  if !@fingerprint.nil? && @fingerprint !~ pattern
    invalid_properties.push("invalid value for \"fingerprint\", must conform to the pattern #{pattern}.")
  end

  if !@user_agent.nil? && @user_agent.to_s.length > 512
    invalid_properties.push('invalid value for "user_agent", the character length must be smaller than or equal to 512.')
  end

  if !@user_agent.nil? && @user_agent.to_s.length < 10
    invalid_properties.push('invalid value for "user_agent", the character length must be greater than or equal to 10.')
  end

  pattern = Regexp.new(/^[ -~]{10,512}$/)
  if !@user_agent.nil? && @user_agent !~ pattern
    invalid_properties.push("invalid value for \"user_agent\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/alogram_payrisk/models/device_info.rb', line 239

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



134
135
136
137
138
139
140
141
142
143
# File 'lib/alogram_payrisk/models/device_info.rb', line 134

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@fingerprint.nil? && @fingerprint.to_s.length > 67
  return false if !@fingerprint.nil? && @fingerprint.to_s.length < 35
  return false if !@fingerprint.nil? && @fingerprint !~ Regexp.new(/^fp_[a-f0-9]{32,64}$/)
  return false if !@user_agent.nil? && @user_agent.to_s.length > 512
  return false if !@user_agent.nil? && @user_agent.to_s.length < 10
  return false if !@user_agent.nil? && @user_agent !~ Regexp.new(/^[ -~]{10,512}$/)
  true
end