Class: AlogramPayRisk::DiscountCode
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- AlogramPayRisk::DiscountCode
- Defined in:
- lib/alogram_payrisk/models/discount_code.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
The monetary value saved by this discount.
-
#code ⇒ Object
The discount code string (e.g., ‘SUMMER20’).
-
#type ⇒ Object
The type of discount applied.
-
#usage_limit_per_user ⇒ Object
Optional: The number of times a single user/device is allowed to use this specific code.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DiscountCode
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DiscountCode
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 91 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::DiscountCode` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::DiscountCode`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'code') self.code = attributes[:'code'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'usage_limit_per_user') self.usage_limit_per_user = attributes[:'usage_limit_per_user'] end end |
Instance Attribute Details
#amount ⇒ Object
The monetary value saved by this discount.
22 23 24 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 22 def amount @amount end |
#code ⇒ Object
The discount code string (e.g., ‘SUMMER20’).
19 20 21 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 19 def code @code end |
#type ⇒ Object
The type of discount applied.
25 26 27 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 25 def type @type end |
#usage_limit_per_user ⇒ Object
Optional: The number of times a single user/device is allowed to use this specific code.
28 29 30 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 28 def usage_limit_per_user @usage_limit_per_user end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 53 def self.attribute_map { :'code' => :'code', :'amount' => :'amount', :'type' => :'type', :'usage_limit_per_user' => :'usageLimitPerUser' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 175 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 87 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 83 def self.openapi_nullable Set.new([ :'code', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 73 def self.openapi_types { :'code' => :'String', :'amount' => :'Float', :'type' => :'String', :'usage_limit_per_user' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
151 152 153 154 155 156 157 158 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 151 def ==(o) return true if self.equal?(o) self.class == o.class && code == o.code && amount == o.amount && type == o.type && usage_limit_per_user == o.usage_limit_per_user end |
#eql?(o) ⇒ Boolean
162 163 164 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 162 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
168 169 170 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 168 def hash [code, amount, type, usage_limit_per_user].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
124 125 126 127 128 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 124 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 197 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
132 133 134 135 136 137 |
# File 'lib/alogram_payrisk/models/discount_code.rb', line 132 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' type_validator = EnumAttributeValidator.new('String', ["percentage", "fixed_amount", "free_shipping", "buy_x_get_y"]) return false unless type_validator.valid?(@type) true end |