Class: AlogramPayRisk::ExternalAssessment
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- AlogramPayRisk::ExternalAssessment
- Defined in:
- lib/alogram_payrisk/models/external_assessment.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#level ⇒ Object
Returns the value of attribute level.
-
#metadata ⇒ Object
Optional key-value pairs providing additional context for the request.
-
#reason_codes ⇒ Object
Raw reason codes provided by the 3rd party vendor.
-
#recommendation ⇒ Object
The specific action recommended by the 3rd party.
-
#score ⇒ Object
The raw score provided by the 3rd party (if applicable).
-
#source ⇒ Object
The provider of the assessment (e.g., ‘shopify’, ‘signifyd’).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExternalAssessment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ExternalAssessment
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::ExternalAssessment` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::ExternalAssessment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'source') self.source = attributes[:'source'] else self.source = nil end if attributes.key?(:'level') self.level = attributes[:'level'] else self.level = nil end if attributes.key?(:'score') self.score = attributes[:'score'] end if attributes.key?(:'recommendation') self.recommendation = attributes[:'recommendation'] end if attributes.key?(:'reason_codes') if (value = attributes[:'reason_codes']).is_a?(Array) self.reason_codes = value end end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end end |
Instance Attribute Details
#level ⇒ Object
Returns the value of attribute level.
21 22 23 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 21 def level @level end |
#metadata ⇒ Object
Optional key-value pairs providing additional context for the request. Each key should be descriptive, and values should not exceed 2048 characters. Each key should be descriptive.
33 34 35 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 33 def @metadata end |
#reason_codes ⇒ Object
Raw reason codes provided by the 3rd party vendor.
30 31 32 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 30 def reason_codes @reason_codes end |
#recommendation ⇒ Object
The specific action recommended by the 3rd party.
27 28 29 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 27 def recommendation @recommendation end |
#score ⇒ Object
The raw score provided by the 3rd party (if applicable).
24 25 26 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 24 def score @score end |
#source ⇒ Object
The provider of the assessment (e.g., ‘shopify’, ‘signifyd’).
19 20 21 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 19 def source @source end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 58 def self.attribute_map { :'source' => :'source', :'level' => :'level', :'score' => :'score', :'recommendation' => :'recommendation', :'reason_codes' => :'reasonCodes', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 245 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 92 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 80 def self.openapi_types { :'source' => :'String', :'level' => :'RiskLevelEnum', :'score' => :'Float', :'recommendation' => :'String', :'reason_codes' => :'Array<String>', :'metadata' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
219 220 221 222 223 224 225 226 227 228 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 219 def ==(o) return true if self.equal?(o) self.class == o.class && source == o.source && level == o.level && score == o.score && recommendation == o.recommendation && reason_codes == o.reason_codes && == o. end |
#eql?(o) ⇒ Boolean
232 233 234 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 232 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
238 239 240 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 238 def hash [source, level, score, recommendation, reason_codes, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @source.nil? invalid_properties.push('invalid value for "source", source cannot be nil.') end if @level.nil? invalid_properties.push('invalid value for "level", level cannot be nil.') end if !@metadata.nil? && @metadata.to_s.length > 2048 invalid_properties.push('invalid value for "metadata", the character length must be smaller than or equal to 2048.') end if !@metadata.nil? && @metadata.to_s.length < 1 invalid_properties.push('invalid value for "metadata", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 267 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
170 171 172 173 174 175 176 177 |
# File 'lib/alogram_payrisk/models/external_assessment.rb', line 170 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @source.nil? return false if @level.nil? return false if !@metadata.nil? && @metadata.to_s.length > 2048 return false if !@metadata.nil? && @metadata.to_s.length < 1 true end |