Class: AlogramPayRisk::ForensicDataApi

Inherits:
Object
  • Object
show all
Defined in:
lib/alogram_payrisk/api/forensic_data_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ForensicDataApi

Returns a new instance of ForensicDataApi.



19
20
21
# File 'lib/alogram_payrisk/api/forensic_data_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/alogram_payrisk/api/forensic_data_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_fraud_scores(tenant_id, opts = {}) ⇒ ScoresSuccessResponse

Query Historical Assessments

Parameters:

  • tenant_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_trace_id (String)

    Echoed or generated trace ID for tracking requests.

  • :x_idempotency_key (String)

    Unique Idempotency-Key sent in the GET request etc.

  • :start_time (String)
  • :end_time (String)
  • :page_size (Integer) — default: default to 50
  • :page_token (String)

Returns:



32
33
34
35
# File 'lib/alogram_payrisk/api/forensic_data_api.rb', line 32

def get_fraud_scores(tenant_id, opts = {})
  data, _status_code, _headers = get_fraud_scores_with_http_info(tenant_id, opts)
  data
end

#get_fraud_scores_with_http_info(tenant_id, opts = {}) ⇒ Array<(ScoresSuccessResponse, Integer, Hash)>

Query Historical Assessments

Parameters:

  • tenant_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_trace_id (String)

    Echoed or generated trace ID for tracking requests.

  • :x_idempotency_key (String)

    Unique Idempotency-Key sent in the GET request etc.

  • :start_time (String)
  • :end_time (String)
  • :page_size (Integer) — default: default to 50
  • :page_token (String)

Returns:

  • (Array<(ScoresSuccessResponse, Integer, Hash)>)

    ScoresSuccessResponse data, response status code and response headers



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/alogram_payrisk/api/forensic_data_api.rb', line 47

def get_fraud_scores_with_http_info(tenant_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ForensicDataApi.get_fraud_scores ...'
  end
  # verify the required parameter 'tenant_id' is set
  if @api_client.config.client_side_validation && tenant_id.nil?
    fail ArgumentError, "Missing the required parameter 'tenant_id' when calling ForensicDataApi.get_fraud_scores"
  end
  if @api_client.config.client_side_validation && tenant_id.to_s.length > 64
    fail ArgumentError, 'invalid value for "tenant_id" when calling ForensicDataApi.get_fraud_scores, the character length must be smaller than or equal to 64.'
  end

  if @api_client.config.client_side_validation && tenant_id.to_s.length < 5
    fail ArgumentError, 'invalid value for "tenant_id" when calling ForensicDataApi.get_fraud_scores, the character length must be greater than or equal to 5.'
  end

  pattern = Regexp.new(/^tid_[a-z0-9\-_]{2,60}$/)
  if @api_client.config.client_side_validation && tenant_id !~ pattern
    fail ArgumentError, "invalid value for 'tenant_id' when calling ForensicDataApi.get_fraud_scores, must conform to the pattern #{pattern}."
  end

  if @api_client.config.client_side_validation && !opts[:'x_trace_id'].nil? && opts[:'x_trace_id'].to_s.length > 36
    fail ArgumentError, 'invalid value for "opts[:"x_trace_id"]" when calling ForensicDataApi.get_fraud_scores, the character length must be smaller than or equal to 36.'
  end

  if @api_client.config.client_side_validation && !opts[:'x_trace_id'].nil? && opts[:'x_trace_id'].to_s.length < 36
    fail ArgumentError, 'invalid value for "opts[:"x_trace_id"]" when calling ForensicDataApi.get_fraud_scores, the character length must be greater than or equal to 36.'
  end

  pattern = Regexp.new(/^trc_[a-f0-9]{32}$/)
  if @api_client.config.client_side_validation && !opts[:'x_trace_id'].nil? && opts[:'x_trace_id'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"x_trace_id\"]' when calling ForensicDataApi.get_fraud_scores, must conform to the pattern #{pattern}."
  end

  if @api_client.config.client_side_validation && !opts[:'x_idempotency_key'].nil? && opts[:'x_idempotency_key'].to_s.length > 36
    fail ArgumentError, 'invalid value for "opts[:"x_idempotency_key"]" when calling ForensicDataApi.get_fraud_scores, the character length must be smaller than or equal to 36.'
  end

  if @api_client.config.client_side_validation && !opts[:'x_idempotency_key'].nil? && opts[:'x_idempotency_key'].to_s.length < 36
    fail ArgumentError, 'invalid value for "opts[:"x_idempotency_key"]" when calling ForensicDataApi.get_fraud_scores, the character length must be greater than or equal to 36.'
  end

  pattern = Regexp.new(/^idk_[a-f0-9]{32}$/)
  if @api_client.config.client_side_validation && !opts[:'x_idempotency_key'].nil? && opts[:'x_idempotency_key'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"x_idempotency_key\"]' when calling ForensicDataApi.get_fraud_scores, must conform to the pattern #{pattern}."
  end

  pattern = Regexp.new(/^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(\.\d{1,9})?(Z|[+-]\d{2}:\d{2})$/)
  if @api_client.config.client_side_validation && !opts[:'start_time'].nil? && opts[:'start_time'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"start_time\"]' when calling ForensicDataApi.get_fraud_scores, must conform to the pattern #{pattern}."
  end

  pattern = Regexp.new(/^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(\.\d{1,9})?(Z|[+-]\d{2}:\d{2})$/)
  if @api_client.config.client_side_validation && !opts[:'end_time'].nil? && opts[:'end_time'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"end_time\"]' when calling ForensicDataApi.get_fraud_scores, must conform to the pattern #{pattern}."
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 500
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling ForensicDataApi.get_fraud_scores, must be smaller than or equal to 500.'
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling ForensicDataApi.get_fraud_scores, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/v1/scores/{tenantId}'.sub('{' + 'tenantId' + '}', CGI.escape(tenant_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'startTime'] = opts[:'start_time'] if !opts[:'start_time'].nil?
  query_params[:'endTime'] = opts[:'end_time'] if !opts[:'end_time'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'pageToken'] = opts[:'page_token'] if !opts[:'page_token'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']
  header_params[:'x-trace-id'] = opts[:'x_trace_id'] if !opts[:'x_trace_id'].nil?
  header_params[:'x-idempotency-key'] = opts[:'x_idempotency_key'] if !opts[:'x_idempotency_key'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ScoresSuccessResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey', 'oAuth2']

  new_options = opts.merge(
    :operation => :"ForensicDataApi.get_fraud_scores",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ForensicDataApi#get_fraud_scores\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end