Class: AlogramPayRisk::FraudScore

Inherits:
ApiModelBase show all
Defined in:
lib/alogram_payrisk/models/fraud_score.rb

Overview

Fraud score for a specific transaction or entity.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FraudScore

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::FraudScore` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::FraudScore`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'risk_level')
    self.risk_level = attributes[:'risk_level']
  else
    self.risk_level = nil
  end

  if attributes.key?(:'confidence')
    self.confidence = attributes[:'confidence']
  end

  if attributes.key?(:'score')
    self.score = attributes[:'score']
  end

  if attributes.key?(:'explanation')
    self.explanation = attributes[:'explanation']
  end
end

Instance Attribute Details

#confidenceObject

Returns the value of attribute confidence.



21
22
23
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 21

def confidence
  @confidence
end

#explanationObject

A human-readable explanation of the fraud score, if available.



27
28
29
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 27

def explanation
  @explanation
end

#risk_levelObject

Returns the value of attribute risk_level.



19
20
21
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 19

def risk_level
  @risk_level
end

#scoreObject

Fraud risk score (0.00 - 1.00).



24
25
26
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 24

def score
  @score
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 52

def self.attribute_map
  {
    :'risk_level' => :'riskLevel',
    :'confidence' => :'confidence',
    :'score' => :'score',
    :'explanation' => :'explanation'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 225

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 72

def self.openapi_types
  {
    :'risk_level' => :'RiskLevelEnum',
    :'confidence' => :'ConfidenceEnum',
    :'score' => :'Float',
    :'explanation' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



201
202
203
204
205
206
207
208
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 201

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      risk_level == o.risk_level &&
      confidence == o.confidence &&
      score == o.score &&
      explanation == o.explanation
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


212
213
214
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 212

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



218
219
220
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 218

def hash
  [risk_level, confidence, score, explanation].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 124

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @risk_level.nil?
    invalid_properties.push('invalid value for "risk_level", risk_level cannot be nil.')
  end

  if !@score.nil? && @score > 1.0
    invalid_properties.push('invalid value for "score", must be smaller than or equal to 1.0.')
  end

  if !@score.nil? && @score < 0.0
    invalid_properties.push('invalid value for "score", must be greater than or equal to 0.0.')
  end

  if !@explanation.nil? && @explanation.to_s.length > 512
    invalid_properties.push('invalid value for "explanation", the character length must be smaller than or equal to 512.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 247

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



148
149
150
151
152
153
154
155
# File 'lib/alogram_payrisk/models/fraud_score.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @risk_level.nil?
  return false if !@score.nil? && @score > 1.0
  return false if !@score.nil? && @score < 0.0
  return false if !@explanation.nil? && @explanation.to_s.length > 512
  true
end