Class: AlogramPayRisk::Integrity

Inherits:
ApiModelBase show all
Defined in:
lib/alogram_payrisk/models/integrity.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Integrity

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/alogram_payrisk/models/integrity.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::Integrity` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::Integrity`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'is_proxy_vpn_tor')
    self.is_proxy_vpn_tor = attributes[:'is_proxy_vpn_tor']
  end

  if attributes.key?(:'is_hosting_provider')
    self.is_hosting_provider = attributes[:'is_hosting_provider']
  end

  if attributes.key?(:'is_headless')
    self.is_headless = attributes[:'is_headless']
  end

  if attributes.key?(:'is_automation')
    self.is_automation = attributes[:'is_automation']
  end

  if attributes.key?(:'is_emulator')
    self.is_emulator = attributes[:'is_emulator']
  end

  if attributes.key?(:'is_rooted_jailbroken')
    self.is_rooted_jailbroken = attributes[:'is_rooted_jailbroken']
  end
end

Instance Attribute Details

#is_automationObject

Indicates whether the request originated from an automated script or bot.



28
29
30
# File 'lib/alogram_payrisk/models/integrity.rb', line 28

def is_automation
  @is_automation
end

#is_emulatorObject

Indicates whether the request originated from an emulator (e.g., Android Emulator, iOS Simulator).



31
32
33
# File 'lib/alogram_payrisk/models/integrity.rb', line 31

def is_emulator
  @is_emulator
end

#is_headlessObject

Indicates whether the browser is running in headless mode (e.g., automated testing, scraping).



25
26
27
# File 'lib/alogram_payrisk/models/integrity.rb', line 25

def is_headless
  @is_headless
end

#is_hosting_providerObject

Indicates whether the IP address belongs to a hosting provider (e.g., data center, cloud provider).



22
23
24
# File 'lib/alogram_payrisk/models/integrity.rb', line 22

def is_hosting_provider
  @is_hosting_provider
end

#is_proxy_vpn_torObject

Indicates whether the IP address is associated with a proxy, VPN, or Tor exit node.



19
20
21
# File 'lib/alogram_payrisk/models/integrity.rb', line 19

def is_proxy_vpn_tor
  @is_proxy_vpn_tor
end

#is_rooted_jailbrokenObject

Indicates whether the device is rooted (Android) or jailbroken (iOS).



34
35
36
# File 'lib/alogram_payrisk/models/integrity.rb', line 34

def is_rooted_jailbroken
  @is_rooted_jailbroken
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/alogram_payrisk/models/integrity.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/alogram_payrisk/models/integrity.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/alogram_payrisk/models/integrity.rb', line 37

def self.attribute_map
  {
    :'is_proxy_vpn_tor' => :'isProxyVpnTor',
    :'is_hosting_provider' => :'isHostingProvider',
    :'is_headless' => :'isHeadless',
    :'is_automation' => :'isAutomation',
    :'is_emulator' => :'isEmulator',
    :'is_rooted_jailbroken' => :'isRootedJailbroken'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/alogram_payrisk/models/integrity.rb', line 160

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/alogram_payrisk/models/integrity.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/alogram_payrisk/models/integrity.rb', line 59

def self.openapi_types
  {
    :'is_proxy_vpn_tor' => :'Boolean',
    :'is_hosting_provider' => :'Boolean',
    :'is_headless' => :'Boolean',
    :'is_automation' => :'Boolean',
    :'is_emulator' => :'Boolean',
    :'is_rooted_jailbroken' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



134
135
136
137
138
139
140
141
142
143
# File 'lib/alogram_payrisk/models/integrity.rb', line 134

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      is_proxy_vpn_tor == o.is_proxy_vpn_tor &&
      is_hosting_provider == o.is_hosting_provider &&
      is_headless == o.is_headless &&
      is_automation == o.is_automation &&
      is_emulator == o.is_emulator &&
      is_rooted_jailbroken == o.is_rooted_jailbroken
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


147
148
149
# File 'lib/alogram_payrisk/models/integrity.rb', line 147

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



153
154
155
# File 'lib/alogram_payrisk/models/integrity.rb', line 153

def hash
  [is_proxy_vpn_tor, is_hosting_provider, is_headless, is_automation, is_emulator, is_rooted_jailbroken].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
# File 'lib/alogram_payrisk/models/integrity.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/alogram_payrisk/models/integrity.rb', line 182

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



127
128
129
130
# File 'lib/alogram_payrisk/models/integrity.rb', line 127

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end