Class: AlogramPayRisk::Interaction
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- AlogramPayRisk::Interaction
- Defined in:
- lib/alogram_payrisk/models/interaction.rb
Overview
The application-layer Interaction object.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#device_info ⇒ Object
Returns the value of attribute device_info.
-
#interaction_type ⇒ Object
Returns the value of attribute interaction_type.
-
#location_id ⇒ Object
Unique identifier for the location where the transaction occurred.
-
#metadata ⇒ Object
Optional key-value pairs providing additional context for the request.
-
#timestamp ⇒ Object
RFC 3339 timestamp with timezone.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Interaction
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Interaction
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::Interaction` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::Interaction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'location_id') self.location_id = attributes[:'location_id'] end if attributes.key?(:'device_info') self.device_info = attributes[:'device_info'] end if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] end if attributes.key?(:'interaction_type') self.interaction_type = attributes[:'interaction_type'] else self.interaction_type = nil end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end end |
Instance Attribute Details
#device_info ⇒ Object
Returns the value of attribute device_info.
22 23 24 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 22 def device_info @device_info end |
#interaction_type ⇒ Object
Returns the value of attribute interaction_type.
27 28 29 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 27 def interaction_type @interaction_type end |
#location_id ⇒ Object
Unique identifier for the location where the transaction occurred.
20 21 22 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 20 def location_id @location_id end |
#metadata ⇒ Object
Optional key-value pairs providing additional context for the request. Each key should be descriptive, and values should not exceed 2048 characters. Each key should be descriptive.
30 31 32 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 30 def @metadata end |
#timestamp ⇒ Object
RFC 3339 timestamp with timezone.
25 26 27 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 25 def @timestamp end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 55 def self.attribute_map { :'location_id' => :'locationId', :'device_info' => :'deviceInfo', :'timestamp' => :'timestamp', :'interaction_type' => :'interactionType', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 264 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 76 def self.openapi_types { :'location_id' => :'String', :'device_info' => :'DeviceInfo', :'timestamp' => :'String', :'interaction_type' => :'InteractionTypeEnum', :'metadata' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
239 240 241 242 243 244 245 246 247 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 239 def ==(o) return true if self.equal?(o) self.class == o.class && location_id == o.location_id && device_info == o.device_info && == o. && interaction_type == o.interaction_type && == o. end |
#eql?(o) ⇒ Boolean
251 252 253 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 251 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
257 258 259 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 257 def hash [location_id, device_info, , interaction_type, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 133 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@location_id.nil? && @location_id.to_s.length > 50 invalid_properties.push('invalid value for "location_id", the character length must be smaller than or equal to 50.') end if !@location_id.nil? && @location_id.to_s.length < 3 invalid_properties.push('invalid value for "location_id", the character length must be greater than or equal to 3.') end pattern = Regexp.new(/^[a-zA-Z0-9\-_]{3,50}$/) if !@location_id.nil? && @location_id !~ pattern invalid_properties.push("invalid value for \"location_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(\.\d{1,9})?(Z|[+-]\d{2}:\d{2})$/) if !@timestamp.nil? && @timestamp !~ pattern invalid_properties.push("invalid value for \"timestamp\", must conform to the pattern #{pattern}.") end if @interaction_type.nil? invalid_properties.push('invalid value for "interaction_type", interaction_type cannot be nil.') end if !@metadata.nil? && @metadata.to_s.length > 2048 invalid_properties.push('invalid value for "metadata", the character length must be smaller than or equal to 2048.') end if !@metadata.nil? && @metadata.to_s.length < 1 invalid_properties.push('invalid value for "metadata", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 286 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/alogram_payrisk/models/interaction.rb', line 171 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@location_id.nil? && @location_id.to_s.length > 50 return false if !@location_id.nil? && @location_id.to_s.length < 3 return false if !@location_id.nil? && @location_id !~ Regexp.new(/^[a-zA-Z0-9\-_]{3,50}$/) return false if !@timestamp.nil? && @timestamp !~ Regexp.new(/^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(\.\d{1,9})?(Z|[+-]\d{2}:\d{2})$/) return false if @interaction_type.nil? return false if !@metadata.nil? && @metadata.to_s.length > 2048 return false if !@metadata.nil? && @metadata.to_s.length < 1 true end |