Class: AlogramPayRisk::IpInfo
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- AlogramPayRisk::IpInfo
- Defined in:
- lib/alogram_payrisk/models/ip_info.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#asn ⇒ Object
Autonomous System Number (ASN) of the IP address.
-
#city ⇒ Object
City associated with the IP address.
-
#company ⇒ Object
Company associated with the IP address.
-
#country ⇒ Object
ISO 3166-1 alpha-2 country code or full country name.
-
#ip_address ⇒ Object
IP address of the customer, client, or user that initiated the request.
-
#ip_prefix ⇒ Object
CIDR, e.g., 198.51.100.0/24 or 2001:db8::/48.
-
#ip_version ⇒ Object
IP protocol version.
-
#ipv6 ⇒ Object
IPv6 address.
-
#org ⇒ Object
Organization associated with the IP address.
-
#postal_code ⇒ Object
Postal code associated with the IP address.
-
#region ⇒ Object
Region associated with the IP address.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IpInfo
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IpInfo
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 125 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::IpInfo` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::IpInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ip_address') self.ip_address = attributes[:'ip_address'] end if attributes.key?(:'ipv6') self.ipv6 = attributes[:'ipv6'] end if attributes.key?(:'ip_version') self.ip_version = attributes[:'ip_version'] else self.ip_version = 'ipv4' end if attributes.key?(:'ip_prefix') self.ip_prefix = attributes[:'ip_prefix'] end if attributes.key?(:'asn') self.asn = attributes[:'asn'] end if attributes.key?(:'org') self.org = attributes[:'org'] end if attributes.key?(:'company') self.company = attributes[:'company'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'region') self.region = attributes[:'region'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] end end |
Instance Attribute Details
#asn ⇒ Object
Autonomous System Number (ASN) of the IP address.
31 32 33 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 31 def asn @asn end |
#city ⇒ Object
City associated with the IP address.
46 47 48 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 46 def city @city end |
#company ⇒ Object
Company associated with the IP address.
37 38 39 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 37 def company @company end |
#country ⇒ Object
ISO 3166-1 alpha-2 country code or full country name.
40 41 42 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 40 def country @country end |
#ip_address ⇒ Object
IP address of the customer, client, or user that initiated the request. Each octet must be between 0 and 255.
19 20 21 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 19 def ip_address @ip_address end |
#ip_prefix ⇒ Object
CIDR, e.g., 198.51.100.0/24 or 2001:db8::/48
28 29 30 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 28 def ip_prefix @ip_prefix end |
#ip_version ⇒ Object
IP protocol version.
25 26 27 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 25 def ip_version @ip_version end |
#ipv6 ⇒ Object
IPv6 address.
22 23 24 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 22 def ipv6 @ipv6 end |
#org ⇒ Object
Organization associated with the IP address.
34 35 36 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 34 def org @org end |
#postal_code ⇒ Object
Postal code associated with the IP address.
49 50 51 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 49 def postal_code @postal_code end |
#region ⇒ Object
Region associated with the IP address.
43 44 45 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 43 def region @region end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
91 92 93 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 91 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
96 97 98 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 96 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 74 def self.attribute_map { :'ip_address' => :'ipAddress', :'ipv6' => :'ipv6', :'ip_version' => :'ipVersion', :'ip_prefix' => :'ipPrefix', :'asn' => :'asn', :'org' => :'org', :'company' => :'company', :'country' => :'country', :'region' => :'region', :'city' => :'city', :'postal_code' => :'postalCode' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 383 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
118 119 120 121 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 118 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 101 def self.openapi_types { :'ip_address' => :'String', :'ipv6' => :'String', :'ip_version' => :'String', :'ip_prefix' => :'String', :'asn' => :'String', :'org' => :'String', :'company' => :'String', :'country' => :'String', :'region' => :'String', :'city' => :'String', :'postal_code' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 352 def ==(o) return true if self.equal?(o) self.class == o.class && ip_address == o.ip_address && ipv6 == o.ipv6 && ip_version == o.ip_version && ip_prefix == o.ip_prefix && asn == o.asn && org == o.org && company == o.company && country == o.country && region == o.region && city == o.city && postal_code == o.postal_code end |
#eql?(o) ⇒ Boolean
370 371 372 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 370 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
376 377 378 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 376 def hash [ip_address, ipv6, ip_version, ip_prefix, asn, org, company, country, region, city, postal_code].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 188 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@ip_address.nil? && @ip_address.to_s.length > 45 invalid_properties.push('invalid value for "ip_address", the character length must be smaller than or equal to 45.') end if !@ip_address.nil? && @ip_address.to_s.length < 7 invalid_properties.push('invalid value for "ip_address", the character length must be greater than or equal to 7.') end pattern = Regexp.new(/^AS\d+$/) if !@asn.nil? && @asn !~ pattern invalid_properties.push("invalid value for \"asn\", must conform to the pattern #{pattern}.") end if !@country.nil? && @country.to_s.length > 64 invalid_properties.push('invalid value for "country", the character length must be smaller than or equal to 64.') end if !@country.nil? && @country.to_s.length < 2 invalid_properties.push('invalid value for "country", the character length must be greater than or equal to 2.') end if !@region.nil? && @region.to_s.length > 60 invalid_properties.push('invalid value for "region", the character length must be smaller than or equal to 60.') end if !@region.nil? && @region.to_s.length < 2 invalid_properties.push('invalid value for "region", the character length must be greater than or equal to 2.') end if !@city.nil? && @city.to_s.length > 60 invalid_properties.push('invalid value for "city", the character length must be smaller than or equal to 60.') end if !@city.nil? && @city.to_s.length < 2 invalid_properties.push('invalid value for "city", the character length must be greater than or equal to 2.') end if !@postal_code.nil? && @postal_code.to_s.length > 10 invalid_properties.push('invalid value for "postal_code", the character length must be smaller than or equal to 10.') end if !@postal_code.nil? && @postal_code.to_s.length < 2 invalid_properties.push('invalid value for "postal_code", the character length must be greater than or equal to 2.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 405 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/alogram_payrisk/models/ip_info.rb', line 241 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@ip_address.nil? && @ip_address.to_s.length > 45 return false if !@ip_address.nil? && @ip_address.to_s.length < 7 ip_version_validator = EnumAttributeValidator.new('String', ["ipv4", "ipv6"]) return false unless ip_version_validator.valid?(@ip_version) return false if !@asn.nil? && @asn !~ Regexp.new(/^AS\d+$/) return false if !@country.nil? && @country.to_s.length > 64 return false if !@country.nil? && @country.to_s.length < 2 return false if !@region.nil? && @region.to_s.length > 60 return false if !@region.nil? && @region.to_s.length < 2 return false if !@city.nil? && @city.to_s.length > 60 return false if !@city.nil? && @city.to_s.length < 2 return false if !@postal_code.nil? && @postal_code.to_s.length > 10 return false if !@postal_code.nil? && @postal_code.to_s.length < 2 true end |