Class: AlogramPayRisk::OrderContext

Inherits:
ApiModelBase show all
Defined in:
lib/alogram_payrisk/models/order_context.rb

Overview

Order context for the purchase.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OrderContext

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/alogram_payrisk/models/order_context.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::OrderContext` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::OrderContext`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'order_id')
    self.order_id = attributes[:'order_id']
  end

  if attributes.key?(:'order_total')
    self.order_total = attributes[:'order_total']
  end

  if attributes.key?(:'shipping_method')
    self.shipping_method = attributes[:'shipping_method']
  end

  if attributes.key?(:'line_item_count')
    self.line_item_count = attributes[:'line_item_count']
  end
end

Instance Attribute Details

#line_item_countObject

Number of items in the order.



29
30
31
# File 'lib/alogram_payrisk/models/order_context.rb', line 29

def line_item_count
  @line_item_count
end

#order_idObject

Unique identifier for the order.



20
21
22
# File 'lib/alogram_payrisk/models/order_context.rb', line 20

def order_id
  @order_id
end

#order_totalObject

Value of the purchase in the specified currency. Must be a positive number with up to two decimal places.



23
24
25
# File 'lib/alogram_payrisk/models/order_context.rb', line 23

def order_total
  @order_total
end

#shipping_methodObject

Shipping method for the order.



26
27
28
# File 'lib/alogram_payrisk/models/order_context.rb', line 26

def shipping_method
  @shipping_method
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/alogram_payrisk/models/order_context.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/alogram_payrisk/models/order_context.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
# File 'lib/alogram_payrisk/models/order_context.rb', line 54

def self.attribute_map
  {
    :'order_id' => :'orderId',
    :'order_total' => :'orderTotal',
    :'shipping_method' => :'shippingMethod',
    :'line_item_count' => :'lineItemCount'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/alogram_payrisk/models/order_context.rb', line 231

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



84
85
86
87
# File 'lib/alogram_payrisk/models/order_context.rb', line 84

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
# File 'lib/alogram_payrisk/models/order_context.rb', line 74

def self.openapi_types
  {
    :'order_id' => :'String',
    :'order_total' => :'Float',
    :'shipping_method' => :'String',
    :'line_item_count' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



207
208
209
210
211
212
213
214
# File 'lib/alogram_payrisk/models/order_context.rb', line 207

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      order_id == o.order_id &&
      order_total == o.order_total &&
      shipping_method == o.shipping_method &&
      line_item_count == o.line_item_count
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


218
219
220
# File 'lib/alogram_payrisk/models/order_context.rb', line 218

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



224
225
226
# File 'lib/alogram_payrisk/models/order_context.rb', line 224

def hash
  [order_id, order_total, shipping_method, line_item_count].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/alogram_payrisk/models/order_context.rb', line 124

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@order_total.nil? && @order_total > 1.0E+7
    invalid_properties.push('invalid value for "order_total", must be smaller than or equal to 1.0E+7.')
  end

  if !@order_total.nil? && @order_total < 0.01
    invalid_properties.push('invalid value for "order_total", must be greater than or equal to 0.01.')
  end

  if !@line_item_count.nil? && @line_item_count > 100
    invalid_properties.push('invalid value for "line_item_count", must be smaller than or equal to 100.')
  end

  if !@line_item_count.nil? && @line_item_count < 0
    invalid_properties.push('invalid value for "line_item_count", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/alogram_payrisk/models/order_context.rb', line 253

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



148
149
150
151
152
153
154
155
156
157
# File 'lib/alogram_payrisk/models/order_context.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@order_total.nil? && @order_total > 1.0E+7
  return false if !@order_total.nil? && @order_total < 0.01
  shipping_method_validator = EnumAttributeValidator.new('String', ["digital", "ship", "bopis"])
  return false unless shipping_method_validator.valid?(@shipping_method)
  return false if !@line_item_count.nil? && @line_item_count > 100
  return false if !@line_item_count.nil? && @line_item_count < 0
  true
end