Class: AlogramPayRisk::ReasonDetail
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- AlogramPayRisk::ReasonDetail
- Defined in:
- lib/alogram_payrisk/models/reason_detail.rb
Overview
Merchant-friendly detail for a specific risk reason.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#category ⇒ Object
Returns the value of attribute category.
-
#code ⇒ Object
Technical reason code (e.g., GEO_COUNTRY_SANCTIONED).
-
#description ⇒ Object
Detailed explanation of the risk signal.
-
#display_name ⇒ Object
Merchant-friendly name for the risk reason.
-
#recommended_action ⇒ Object
Suggested action for the merchant to mitigate this specific risk.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ReasonDetail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ReasonDetail
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::ReasonDetail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::ReasonDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'code') self.code = attributes[:'code'] else self.code = nil end if attributes.key?(:'category') self.category = attributes[:'category'] else self.category = nil end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] else self.display_name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'recommended_action') self.recommended_action = attributes[:'recommended_action'] end end |
Instance Attribute Details
#category ⇒ Object
Returns the value of attribute category.
22 23 24 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 22 def category @category end |
#code ⇒ Object
Technical reason code (e.g., GEO_COUNTRY_SANCTIONED).
20 21 22 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 20 def code @code end |
#description ⇒ Object
Detailed explanation of the risk signal.
28 29 30 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 28 def description @description end |
#display_name ⇒ Object
Merchant-friendly name for the risk reason.
25 26 27 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 25 def display_name @display_name end |
#recommended_action ⇒ Object
Suggested action for the merchant to mitigate this specific risk.
31 32 33 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 31 def recommended_action @recommended_action end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 56 def self.attribute_map { :'code' => :'code', :'category' => :'category', :'display_name' => :'displayName', :'description' => :'description', :'recommended_action' => :'recommendedAction' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 223 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 77 def self.openapi_types { :'code' => :'String', :'category' => :'RiskCategoryEnum', :'display_name' => :'String', :'description' => :'String', :'recommended_action' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
198 199 200 201 202 203 204 205 206 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 198 def ==(o) return true if self.equal?(o) self.class == o.class && code == o.code && category == o.category && display_name == o.display_name && description == o.description && recommended_action == o.recommended_action end |
#eql?(o) ⇒ Boolean
210 211 212 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 210 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 216 def hash [code, category, display_name, description, recommended_action].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @code.nil? invalid_properties.push('invalid value for "code", code cannot be nil.') end if @category.nil? invalid_properties.push('invalid value for "category", category cannot be nil.') end if @display_name.nil? invalid_properties.push('invalid value for "display_name", display_name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 245 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
158 159 160 161 162 163 164 |
# File 'lib/alogram_payrisk/models/reason_detail.rb', line 158 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @code.nil? return false if @category.nil? return false if @display_name.nil? true end |