Class: AlogramPayRisk::RiskScoringApi
- Inherits:
-
Object
- Object
- AlogramPayRisk::RiskScoringApi
- Defined in:
- lib/alogram_payrisk/api/risk_scoring_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ RiskScoringApi
constructor
A new instance of RiskScoringApi.
-
#risk_check(x_idempotency_key, check_request, opts = {}) ⇒ DecisionResponse
Assess Transaction Risk.
-
#risk_check_with_http_info(x_idempotency_key, check_request, opts = {}) ⇒ Array<(DecisionResponse, Integer, Hash)>
Assess Transaction Risk.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ RiskScoringApi
Returns a new instance of RiskScoringApi.
19 20 21 |
# File 'lib/alogram_payrisk/api/risk_scoring_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/alogram_payrisk/api/risk_scoring_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#risk_check(x_idempotency_key, check_request, opts = {}) ⇒ DecisionResponse
Assess Transaction Risk
28 29 30 31 |
# File 'lib/alogram_payrisk/api/risk_scoring_api.rb', line 28 def risk_check(x_idempotency_key, check_request, opts = {}) data, _status_code, _headers = risk_check_with_http_info(x_idempotency_key, check_request, opts) data end |
#risk_check_with_http_info(x_idempotency_key, check_request, opts = {}) ⇒ Array<(DecisionResponse, Integer, Hash)>
Assess Transaction Risk
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/alogram_payrisk/api/risk_scoring_api.rb', line 39 def risk_check_with_http_info(x_idempotency_key, check_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RiskScoringApi.risk_check ...' end # verify the required parameter 'x_idempotency_key' is set if @api_client.config.client_side_validation && x_idempotency_key.nil? fail ArgumentError, "Missing the required parameter 'x_idempotency_key' when calling RiskScoringApi.risk_check" end if @api_client.config.client_side_validation && x_idempotency_key.to_s.length > 36 fail ArgumentError, 'invalid value for "x_idempotency_key" when calling RiskScoringApi.risk_check, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && x_idempotency_key.to_s.length < 36 fail ArgumentError, 'invalid value for "x_idempotency_key" when calling RiskScoringApi.risk_check, the character length must be greater than or equal to 36.' end pattern = Regexp.new(/^idk_[a-f0-9]{32}$/) if @api_client.config.client_side_validation && x_idempotency_key !~ pattern fail ArgumentError, "invalid value for 'x_idempotency_key' when calling RiskScoringApi.risk_check, must conform to the pattern #{pattern}." end # verify the required parameter 'check_request' is set if @api_client.config.client_side_validation && check_request.nil? fail ArgumentError, "Missing the required parameter 'check_request' when calling RiskScoringApi.risk_check" end if @api_client.config.client_side_validation && !opts[:'x_trace_id'].nil? && opts[:'x_trace_id'].to_s.length > 36 fail ArgumentError, 'invalid value for "opts[:"x_trace_id"]" when calling RiskScoringApi.risk_check, the character length must be smaller than or equal to 36.' end if @api_client.config.client_side_validation && !opts[:'x_trace_id'].nil? && opts[:'x_trace_id'].to_s.length < 36 fail ArgumentError, 'invalid value for "opts[:"x_trace_id"]" when calling RiskScoringApi.risk_check, the character length must be greater than or equal to 36.' end pattern = Regexp.new(/^trc_[a-f0-9]{32}$/) if @api_client.config.client_side_validation && !opts[:'x_trace_id'].nil? && opts[:'x_trace_id'] !~ pattern fail ArgumentError, "invalid value for 'opts[:\"x_trace_id\"]' when calling RiskScoringApi.risk_check, must conform to the pattern #{pattern}." end # resource path local_var_path = '/v1/risk/check' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'x-idempotency-key'] = x_idempotency_key header_params[:'x-trace-id'] = opts[:'x_trace_id'] if !opts[:'x_trace_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(check_request) # return_type return_type = opts[:debug_return_type] || 'DecisionResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey', 'oAuth2'] = opts.merge( :operation => :"RiskScoringApi.risk_check", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RiskScoringApi#risk_check\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |