Class: AlogramPayRisk::ScoreRecord
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- AlogramPayRisk::ScoreRecord
- Defined in:
- lib/alogram_payrisk/models/score_record.rb
Overview
Fraud score for a specific transaction or entity.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
Value of the purchase in the specified currency.
-
#breakdown ⇒ Object
Returns the value of attribute breakdown.
-
#currency ⇒ Object
ISO 4217 currency code (e.g., ‘USD’).
-
#decision ⇒ Object
The synchronous risk decision for a purchase.
-
#decision_at ⇒ Object
RFC 3339 timestamp with timezone.
-
#entities ⇒ Object
Returns the value of attribute entities.
-
#id ⇒ Object
Universal, authoritative transaction and evaluation identifier.
-
#reasons ⇒ Object
Structured reason details for the score.
-
#risk_score ⇒ Object
The authoritative, policy-adjusted blended risk score (0.0 - 1.0) derived from expert fusion.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ScoreRecord
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ScoreRecord
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::ScoreRecord` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::ScoreRecord`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'decision_at') self.decision_at = attributes[:'decision_at'] else self.decision_at = nil end if attributes.key?(:'decision') self.decision = attributes[:'decision'] else self.decision = nil end if attributes.key?(:'risk_score') self.risk_score = attributes[:'risk_score'] else self.risk_score = nil end if attributes.key?(:'breakdown') self.breakdown = attributes[:'breakdown'] end if attributes.key?(:'reasons') if (value = attributes[:'reasons']).is_a?(Array) self.reasons = value end end if attributes.key?(:'entities') self.entities = attributes[:'entities'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end end |
Instance Attribute Details
#amount ⇒ Object
Value of the purchase in the specified currency. Must be a positive number with up to two decimal places.
39 40 41 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 39 def amount @amount end |
#breakdown ⇒ Object
Returns the value of attribute breakdown.
31 32 33 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 31 def breakdown @breakdown end |
#currency ⇒ Object
ISO 4217 currency code (e.g., ‘USD’).
42 43 44 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 42 def currency @currency end |
#decision ⇒ Object
The synchronous risk decision for a purchase.
26 27 28 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 26 def decision @decision end |
#decision_at ⇒ Object
RFC 3339 timestamp with timezone.
23 24 25 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 23 def decision_at @decision_at end |
#entities ⇒ Object
Returns the value of attribute entities.
36 37 38 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 36 def entities @entities end |
#id ⇒ Object
Universal, authoritative transaction and evaluation identifier. Prefixed with ‘pi_’ for purchases.
20 21 22 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 20 def id @id end |
#reasons ⇒ Object
Structured reason details for the score.
34 35 36 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 34 def reasons @reasons end |
#risk_score ⇒ Object
The authoritative, policy-adjusted blended risk score (0.0 - 1.0) derived from expert fusion.
29 30 31 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 29 def risk_score @risk_score end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
82 83 84 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 82 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
87 88 89 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 87 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 67 def self.attribute_map { :'id' => :'id', :'decision_at' => :'decisionAt', :'decision' => :'decision', :'risk_score' => :'riskScore', :'breakdown' => :'breakdown', :'reasons' => :'reasons', :'entities' => :'entities', :'amount' => :'amount', :'currency' => :'currency' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 369 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 107 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 92 def self.openapi_types { :'id' => :'String', :'decision_at' => :'String', :'decision' => :'String', :'risk_score' => :'Float', :'breakdown' => :'RiskBreakdown', :'reasons' => :'Array<ReasonDetail>', :'entities' => :'EntityIds', :'amount' => :'Float', :'currency' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 340 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && decision_at == o.decision_at && decision == o.decision && risk_score == o.risk_score && breakdown == o.breakdown && reasons == o.reasons && entities == o.entities && amount == o.amount && currency == o.currency end |
#eql?(o) ⇒ Boolean
356 357 358 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 356 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
362 363 364 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 362 def hash [id, decision_at, decision, risk_score, breakdown, reasons, entities, amount, currency].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 177 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @decision_at.nil? invalid_properties.push('invalid value for "decision_at", decision_at cannot be nil.') end pattern = Regexp.new(/^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(\.\d{1,9})?(Z|[+-]\d{2}:\d{2})$/) if @decision_at !~ pattern invalid_properties.push("invalid value for \"decision_at\", must conform to the pattern #{pattern}.") end if @decision.nil? invalid_properties.push('invalid value for "decision", decision cannot be nil.') end if @risk_score.nil? invalid_properties.push('invalid value for "risk_score", risk_score cannot be nil.') end if @risk_score > 1.0 invalid_properties.push('invalid value for "risk_score", must be smaller than or equal to 1.0.') end if @risk_score < 0.0 invalid_properties.push('invalid value for "risk_score", must be greater than or equal to 0.0.') end if !@amount.nil? && @amount > 1.0E+7 invalid_properties.push('invalid value for "amount", must be smaller than or equal to 1.0E+7.') end if !@amount.nil? && @amount < 0.01 invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.01.') end if !@currency.nil? && @currency.to_s.length > 3 invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.') end if !@currency.nil? && @currency.to_s.length < 3 invalid_properties.push('invalid value for "currency", the character length must be greater than or equal to 3.') end pattern = Regexp.new(/^[A-Z]{3}$/) if !@currency.nil? && @currency !~ pattern invalid_properties.push("invalid value for \"currency\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
391 392 393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 391 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 235 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @decision_at.nil? return false if @decision_at !~ Regexp.new(/^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(\.\d{1,9})?(Z|[+-]\d{2}:\d{2})$/) return false if @decision.nil? decision_validator = EnumAttributeValidator.new('String', ["approve", "review", "decline", "step_up"]) return false unless decision_validator.valid?(@decision) return false if @risk_score.nil? return false if @risk_score > 1.0 return false if @risk_score < 0.0 return false if !@amount.nil? && @amount > 1.0E+7 return false if !@amount.nil? && @amount < 0.01 return false if !@currency.nil? && @currency.to_s.length > 3 return false if !@currency.nil? && @currency.to_s.length < 3 return false if !@currency.nil? && @currency !~ Regexp.new(/^[A-Z]{3}$/) true end |