Class: AlogramPayRisk::SignalIntelligenceApi

Inherits:
Object
  • Object
show all
Defined in:
lib/alogram_payrisk/api/signal_intelligence_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ SignalIntelligenceApi

Returns a new instance of SignalIntelligenceApi.



19
20
21
# File 'lib/alogram_payrisk/api/signal_intelligence_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/alogram_payrisk/api/signal_intelligence_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#ingest_payment_event(x_idempotency_key, payment_event, opts = {}) ⇒ IngestPaymentEvent202Response

Ingest Lifecycle Signals

Parameters:

  • x_idempotency_key (String)

    Unique Idempotency-Key sent in the POST request etc.

  • payment_event (PaymentEvent)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_trace_id (String)

    Echoed or generated trace ID for tracking requests.

  • :x_alogram_agent_manifest (AgentManifest)

    JSON-encoded AgentManifest for autonomous shopping agents. Required for machine-to-machine trust validation (UCP/MCP).

Returns:



29
30
31
32
# File 'lib/alogram_payrisk/api/signal_intelligence_api.rb', line 29

def ingest_payment_event(x_idempotency_key, payment_event, opts = {})
  data, _status_code, _headers = ingest_payment_event_with_http_info(x_idempotency_key, payment_event, opts)
  data
end

#ingest_payment_event_with_http_info(x_idempotency_key, payment_event, opts = {}) ⇒ Array<(IngestPaymentEvent202Response, Integer, Hash)>

Ingest Lifecycle Signals

Parameters:

  • x_idempotency_key (String)

    Unique Idempotency-Key sent in the POST request etc.

  • payment_event (PaymentEvent)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_trace_id (String)

    Echoed or generated trace ID for tracking requests.

  • :x_alogram_agent_manifest (AgentManifest)

    JSON-encoded AgentManifest for autonomous shopping agents. Required for machine-to-machine trust validation (UCP/MCP).

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/alogram_payrisk/api/signal_intelligence_api.rb', line 41

def ingest_payment_event_with_http_info(x_idempotency_key, payment_event, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SignalIntelligenceApi.ingest_payment_event ...'
  end
  # verify the required parameter 'x_idempotency_key' is set
  if @api_client.config.client_side_validation && x_idempotency_key.nil?
    fail ArgumentError, "Missing the required parameter 'x_idempotency_key' when calling SignalIntelligenceApi.ingest_payment_event"
  end
  if @api_client.config.client_side_validation && x_idempotency_key.to_s.length > 36
    fail ArgumentError, 'invalid value for "x_idempotency_key" when calling SignalIntelligenceApi.ingest_payment_event, the character length must be smaller than or equal to 36.'
  end

  if @api_client.config.client_side_validation && x_idempotency_key.to_s.length < 36
    fail ArgumentError, 'invalid value for "x_idempotency_key" when calling SignalIntelligenceApi.ingest_payment_event, the character length must be greater than or equal to 36.'
  end

  pattern = Regexp.new(/^idk_[a-f0-9]{32}$/)
  if @api_client.config.client_side_validation && x_idempotency_key !~ pattern
    fail ArgumentError, "invalid value for 'x_idempotency_key' when calling SignalIntelligenceApi.ingest_payment_event, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'payment_event' is set
  if @api_client.config.client_side_validation && payment_event.nil?
    fail ArgumentError, "Missing the required parameter 'payment_event' when calling SignalIntelligenceApi.ingest_payment_event"
  end
  if @api_client.config.client_side_validation && !opts[:'x_trace_id'].nil? && opts[:'x_trace_id'].to_s.length > 36
    fail ArgumentError, 'invalid value for "opts[:"x_trace_id"]" when calling SignalIntelligenceApi.ingest_payment_event, the character length must be smaller than or equal to 36.'
  end

  if @api_client.config.client_side_validation && !opts[:'x_trace_id'].nil? && opts[:'x_trace_id'].to_s.length < 36
    fail ArgumentError, 'invalid value for "opts[:"x_trace_id"]" when calling SignalIntelligenceApi.ingest_payment_event, the character length must be greater than or equal to 36.'
  end

  pattern = Regexp.new(/^trc_[a-f0-9]{32}$/)
  if @api_client.config.client_side_validation && !opts[:'x_trace_id'].nil? && opts[:'x_trace_id'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"x_trace_id\"]' when calling SignalIntelligenceApi.ingest_payment_event, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/v1/events'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'x-idempotency-key'] = x_idempotency_key
  header_params[:'x-trace-id'] = opts[:'x_trace_id'] if !opts[:'x_trace_id'].nil?
  header_params[:'x-alogram-agent-manifest'] = opts[:'x_alogram_agent_manifest'] if !opts[:'x_alogram_agent_manifest'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(payment_event)

  # return_type
  return_type = opts[:debug_return_type] || 'IngestPaymentEvent202Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey', 'oAuth2']

  new_options = opts.merge(
    :operation => :"SignalIntelligenceApi.ingest_payment_event",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SignalIntelligenceApi#ingest_payment_event\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#ingest_signals(x_idempotency_key, signals_request, opts = {}) ⇒ IngestPaymentEvent202Response

Submit Behavioral Intelligence

Parameters:

  • x_idempotency_key (String)

    Unique Idempotency-Key sent in the POST request etc.

  • signals_request (SignalsRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_trace_id (String)

    Echoed or generated trace ID for tracking requests.

  • :x_alogram_agent_manifest (AgentManifest)

    JSON-encoded AgentManifest for autonomous shopping agents. Required for machine-to-machine trust validation (UCP/MCP).

Returns:



134
135
136
137
# File 'lib/alogram_payrisk/api/signal_intelligence_api.rb', line 134

def ingest_signals(x_idempotency_key, signals_request, opts = {})
  data, _status_code, _headers = ingest_signals_with_http_info(x_idempotency_key, signals_request, opts)
  data
end

#ingest_signals_with_http_info(x_idempotency_key, signals_request, opts = {}) ⇒ Array<(IngestPaymentEvent202Response, Integer, Hash)>

Submit Behavioral Intelligence

Parameters:

  • x_idempotency_key (String)

    Unique Idempotency-Key sent in the POST request etc.

  • signals_request (SignalsRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_trace_id (String)

    Echoed or generated trace ID for tracking requests.

  • :x_alogram_agent_manifest (AgentManifest)

    JSON-encoded AgentManifest for autonomous shopping agents. Required for machine-to-machine trust validation (UCP/MCP).

Returns:



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/alogram_payrisk/api/signal_intelligence_api.rb', line 146

def ingest_signals_with_http_info(x_idempotency_key, signals_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SignalIntelligenceApi.ingest_signals ...'
  end
  # verify the required parameter 'x_idempotency_key' is set
  if @api_client.config.client_side_validation && x_idempotency_key.nil?
    fail ArgumentError, "Missing the required parameter 'x_idempotency_key' when calling SignalIntelligenceApi.ingest_signals"
  end
  if @api_client.config.client_side_validation && x_idempotency_key.to_s.length > 36
    fail ArgumentError, 'invalid value for "x_idempotency_key" when calling SignalIntelligenceApi.ingest_signals, the character length must be smaller than or equal to 36.'
  end

  if @api_client.config.client_side_validation && x_idempotency_key.to_s.length < 36
    fail ArgumentError, 'invalid value for "x_idempotency_key" when calling SignalIntelligenceApi.ingest_signals, the character length must be greater than or equal to 36.'
  end

  pattern = Regexp.new(/^idk_[a-f0-9]{32}$/)
  if @api_client.config.client_side_validation && x_idempotency_key !~ pattern
    fail ArgumentError, "invalid value for 'x_idempotency_key' when calling SignalIntelligenceApi.ingest_signals, must conform to the pattern #{pattern}."
  end

  # verify the required parameter 'signals_request' is set
  if @api_client.config.client_side_validation && signals_request.nil?
    fail ArgumentError, "Missing the required parameter 'signals_request' when calling SignalIntelligenceApi.ingest_signals"
  end
  if @api_client.config.client_side_validation && !opts[:'x_trace_id'].nil? && opts[:'x_trace_id'].to_s.length > 36
    fail ArgumentError, 'invalid value for "opts[:"x_trace_id"]" when calling SignalIntelligenceApi.ingest_signals, the character length must be smaller than or equal to 36.'
  end

  if @api_client.config.client_side_validation && !opts[:'x_trace_id'].nil? && opts[:'x_trace_id'].to_s.length < 36
    fail ArgumentError, 'invalid value for "opts[:"x_trace_id"]" when calling SignalIntelligenceApi.ingest_signals, the character length must be greater than or equal to 36.'
  end

  pattern = Regexp.new(/^trc_[a-f0-9]{32}$/)
  if @api_client.config.client_side_validation && !opts[:'x_trace_id'].nil? && opts[:'x_trace_id'] !~ pattern
    fail ArgumentError, "invalid value for 'opts[:\"x_trace_id\"]' when calling SignalIntelligenceApi.ingest_signals, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/v1/signals'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'x-idempotency-key'] = x_idempotency_key
  header_params[:'x-trace-id'] = opts[:'x_trace_id'] if !opts[:'x_trace_id'].nil?
  header_params[:'x-alogram-agent-manifest'] = opts[:'x_alogram_agent_manifest'] if !opts[:'x_alogram_agent_manifest'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(signals_request)

  # return_type
  return_type = opts[:debug_return_type] || 'IngestPaymentEvent202Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey', 'oAuth2']

  new_options = opts.merge(
    :operation => :"SignalIntelligenceApi.ingest_signals",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SignalIntelligenceApi#ingest_signals\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end