Class: AlogramPayRisk::SignalsInteractionVariant

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/alogram_payrisk/models/signals_interaction_variant.rb

Overview

Interaction batch signal variant (one or more user interactions).

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SignalsInteractionVariant

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/alogram_payrisk/models/signals_interaction_variant.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::SignalsInteractionVariant` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::SignalsInteractionVariant`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'signal_type')
    self.signal_type = attributes[:'signal_type']
  else
    self.signal_type = nil
  end

  if attributes.key?(:'entities')
    self.entities = attributes[:'entities']
  else
    self.entities = nil
  end

  if attributes.key?(:'interactions')
    if (value = attributes[:'interactions']).is_a?(Array)
      self.interactions = value
    end
  else
    self.interactions = nil
  end
end

Instance Attribute Details

#entitiesObject

Returns the value of attribute entities.



22
23
24
# File 'lib/alogram_payrisk/models/signals_interaction_variant.rb', line 22

def entities
  @entities
end

#interactionsObject

One or more interactions associated with the signal.



25
26
27
# File 'lib/alogram_payrisk/models/signals_interaction_variant.rb', line 25

def interactions
  @interactions
end

#signal_typeObject

Value for interaction signals.



20
21
22
# File 'lib/alogram_payrisk/models/signals_interaction_variant.rb', line 20

def signal_type
  @signal_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



59
60
61
# File 'lib/alogram_payrisk/models/signals_interaction_variant.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/alogram_payrisk/models/signals_interaction_variant.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
# File 'lib/alogram_payrisk/models/signals_interaction_variant.rb', line 50

def self.attribute_map
  {
    :'signal_type' => :'signalType',
    :'entities' => :'entities',
    :'interactions' => :'interactions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/alogram_payrisk/models/signals_interaction_variant.rb', line 224

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
# File 'lib/alogram_payrisk/models/signals_interaction_variant.rb', line 78

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
# File 'lib/alogram_payrisk/models/signals_interaction_variant.rb', line 69

def self.openapi_types
  {
    :'signal_type' => :'String',
    :'entities' => :'EntityIds',
    :'interactions' => :'Array<Interaction>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



201
202
203
204
205
206
207
# File 'lib/alogram_payrisk/models/signals_interaction_variant.rb', line 201

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      signal_type == o.signal_type &&
      entities == o.entities &&
      interactions == o.interactions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


211
212
213
# File 'lib/alogram_payrisk/models/signals_interaction_variant.rb', line 211

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



217
218
219
# File 'lib/alogram_payrisk/models/signals_interaction_variant.rb', line 217

def hash
  [signal_type, entities, interactions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/alogram_payrisk/models/signals_interaction_variant.rb', line 122

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @signal_type.nil?
    invalid_properties.push('invalid value for "signal_type", signal_type cannot be nil.')
  end

  if @entities.nil?
    invalid_properties.push('invalid value for "entities", entities cannot be nil.')
  end

  if @interactions.nil?
    invalid_properties.push('invalid value for "interactions", interactions cannot be nil.')
  end

  if @interactions.length > 1000
    invalid_properties.push('invalid value for "interactions", number of items must be less than or equal to 1000.')
  end

  if @interactions.length < 1
    invalid_properties.push('invalid value for "interactions", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/alogram_payrisk/models/signals_interaction_variant.rb', line 246

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



150
151
152
153
154
155
156
157
158
159
160
# File 'lib/alogram_payrisk/models/signals_interaction_variant.rb', line 150

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @signal_type.nil?
  signal_type_validator = EnumAttributeValidator.new('String', ["interaction"])
  return false unless signal_type_validator.valid?(@signal_type)
  return false if @entities.nil?
  return false if @interactions.nil?
  return false if @interactions.length > 1000
  return false if @interactions.length < 1
  true
end