Class: AlogramPayRisk::Card
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- AlogramPayRisk::Card
- Defined in:
- lib/alogram_payrisk/models/card.rb
Overview
Card attributes (network, BIN/IIN, issuer country, AVS/CVV, SCA, optional 3DS).
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#avs_result ⇒ Object
Returns the value of attribute avs_result.
-
#bin ⇒ Object
Bank Identification Number (IIN).
-
#card_network ⇒ Object
Returns the value of attribute card_network.
-
#card_type ⇒ Object
Returns the value of attribute card_type.
-
#cvv_result ⇒ Object
Returns the value of attribute cvv_result.
-
#issuer_country ⇒ Object
ISO 3166-1 alpha-2 country code.
-
#sca_method ⇒ Object
Returns the value of attribute sca_method.
-
#three_ds ⇒ Object
Returns the value of attribute three_ds.
-
#type ⇒ Object
Fixed to ‘card` for this schema.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Card
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Card
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/alogram_payrisk/models/card.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::Card` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::Card`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'card_network') self.card_network = attributes[:'card_network'] end if attributes.key?(:'card_type') self.card_type = attributes[:'card_type'] end if attributes.key?(:'bin') self.bin = attributes[:'bin'] end if attributes.key?(:'issuer_country') self.issuer_country = attributes[:'issuer_country'] end if attributes.key?(:'avs_result') self.avs_result = attributes[:'avs_result'] end if attributes.key?(:'cvv_result') self.cvv_result = attributes[:'cvv_result'] end if attributes.key?(:'sca_method') self.sca_method = attributes[:'sca_method'] end if attributes.key?(:'three_ds') self.three_ds = attributes[:'three_ds'] end end |
Instance Attribute Details
#avs_result ⇒ Object
Returns the value of attribute avs_result.
32 33 34 |
# File 'lib/alogram_payrisk/models/card.rb', line 32 def avs_result @avs_result end |
#bin ⇒ Object
Bank Identification Number (IIN). First 6-8 digits of the PAN; do not send full PAN.
27 28 29 |
# File 'lib/alogram_payrisk/models/card.rb', line 27 def bin @bin end |
#card_network ⇒ Object
Returns the value of attribute card_network.
22 23 24 |
# File 'lib/alogram_payrisk/models/card.rb', line 22 def card_network @card_network end |
#card_type ⇒ Object
Returns the value of attribute card_type.
24 25 26 |
# File 'lib/alogram_payrisk/models/card.rb', line 24 def card_type @card_type end |
#cvv_result ⇒ Object
Returns the value of attribute cvv_result.
34 35 36 |
# File 'lib/alogram_payrisk/models/card.rb', line 34 def cvv_result @cvv_result end |
#issuer_country ⇒ Object
ISO 3166-1 alpha-2 country code.
30 31 32 |
# File 'lib/alogram_payrisk/models/card.rb', line 30 def issuer_country @issuer_country end |
#sca_method ⇒ Object
Returns the value of attribute sca_method.
36 37 38 |
# File 'lib/alogram_payrisk/models/card.rb', line 36 def sca_method @sca_method end |
#three_ds ⇒ Object
Returns the value of attribute three_ds.
38 39 40 |
# File 'lib/alogram_payrisk/models/card.rb', line 38 def three_ds @three_ds end |
#type ⇒ Object
Fixed to ‘card` for this schema.
20 21 22 |
# File 'lib/alogram_payrisk/models/card.rb', line 20 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/alogram_payrisk/models/card.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/alogram_payrisk/models/card.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/alogram_payrisk/models/card.rb', line 63 def self.attribute_map { :'type' => :'type', :'card_network' => :'cardNetwork', :'card_type' => :'cardType', :'bin' => :'bin', :'issuer_country' => :'issuerCountry', :'avs_result' => :'avsResult', :'cvv_result' => :'cvvResult', :'sca_method' => :'scaMethod', :'three_ds' => :'threeDS' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/alogram_payrisk/models/card.rb', line 304 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/alogram_payrisk/models/card.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/alogram_payrisk/models/card.rb', line 88 def self.openapi_types { :'type' => :'String', :'card_network' => :'CardNetworkEnum', :'card_type' => :'PaymentCardTypeEnum', :'bin' => :'String', :'issuer_country' => :'String', :'avs_result' => :'AvsResultEnum', :'cvv_result' => :'CvvResultEnum', :'sca_method' => :'ScaMethodEnum', :'three_ds' => :'ThreeDSData' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/alogram_payrisk/models/card.rb', line 275 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && card_network == o.card_network && card_type == o.card_type && bin == o.bin && issuer_country == o.issuer_country && avs_result == o.avs_result && cvv_result == o.cvv_result && sca_method == o.sca_method && three_ds == o.three_ds end |
#eql?(o) ⇒ Boolean
291 292 293 |
# File 'lib/alogram_payrisk/models/card.rb', line 291 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
297 298 299 |
# File 'lib/alogram_payrisk/models/card.rb', line 297 def hash [type, card_network, card_type, bin, issuer_country, avs_result, cvv_result, sca_method, three_ds].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/alogram_payrisk/models/card.rb', line 165 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if !@bin.nil? && @bin.to_s.length > 8 invalid_properties.push('invalid value for "bin", the character length must be smaller than or equal to 8.') end if !@bin.nil? && @bin.to_s.length < 6 invalid_properties.push('invalid value for "bin", the character length must be greater than or equal to 6.') end pattern = Regexp.new(/^[0-9]{6,8}$/) if !@bin.nil? && @bin !~ pattern invalid_properties.push("invalid value for \"bin\", must conform to the pattern #{pattern}.") end if !@issuer_country.nil? && @issuer_country.to_s.length > 2 invalid_properties.push('invalid value for "issuer_country", the character length must be smaller than or equal to 2.') end if !@issuer_country.nil? && @issuer_country.to_s.length < 2 invalid_properties.push('invalid value for "issuer_country", the character length must be greater than or equal to 2.') end pattern = Regexp.new(/^[A-Z]{2}$/) if !@issuer_country.nil? && @issuer_country !~ pattern invalid_properties.push("invalid value for \"issuer_country\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/alogram_payrisk/models/card.rb', line 326 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/alogram_payrisk/models/card.rb', line 203 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["card"]) return false unless type_validator.valid?(@type) return false if !@bin.nil? && @bin.to_s.length > 8 return false if !@bin.nil? && @bin.to_s.length < 6 return false if !@bin.nil? && @bin !~ Regexp.new(/^[0-9]{6,8}$/) return false if !@issuer_country.nil? && @issuer_country.to_s.length > 2 return false if !@issuer_country.nil? && @issuer_country.to_s.length < 2 return false if !@issuer_country.nil? && @issuer_country !~ Regexp.new(/^[A-Z]{2}$/) true end |