Class: AlogramPayRisk::DecisionResponse

Inherits:
ApiModelBase show all
Defined in:
lib/alogram_payrisk/models/decision_response.rb

Overview

The synchronous risk decision for a purchase.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DecisionResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/alogram_payrisk/models/decision_response.rb', line 137

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::DecisionResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::DecisionResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'assessment_id')
    self.assessment_id = attributes[:'assessment_id']
  else
    self.assessment_id = nil
  end

  if attributes.key?(:'decision')
    self.decision = attributes[:'decision']
  else
    self.decision = nil
  end

  if attributes.key?(:'decision_at')
    self.decision_at = attributes[:'decision_at']
  else
    self.decision_at = nil
  end

  if attributes.key?(:'risk_score')
    self.risk_score = attributes[:'risk_score']
  else
    self.risk_score = nil
  end

  if attributes.key?(:'decision_score')
    self.decision_score = attributes[:'decision_score']
  else
    self.decision_score = nil
  end

  if attributes.key?(:'fraud_score')
    self.fraud_score = attributes[:'fraud_score']
  end

  if attributes.key?(:'breakdown')
    self.breakdown = attributes[:'breakdown']
  end

  if attributes.key?(:'reason_codes')
    if (value = attributes[:'reason_codes']).is_a?(Array)
      self.reason_codes = value
    end
  end

  if attributes.key?(:'reasons')
    if (value = attributes[:'reasons']).is_a?(Array)
      self.reasons = value
    end
  end

  if attributes.key?(:'actions')
    if (value = attributes[:'actions']).is_a?(Array)
      self.actions = value
    end
  end

  if attributes.key?(:'payment_intent_id')
    self.payment_intent_id = attributes[:'payment_intent_id']
  end

  if attributes.key?(:'policy_version')
    self.policy_version = attributes[:'policy_version']
  end

  if attributes.key?(:'model_version')
    self.model_version = attributes[:'model_version']
  end

  if attributes.key?(:'ttl_seconds')
    self.ttl_seconds = attributes[:'ttl_seconds']
  end
end

Instance Attribute Details

#actionsObject

Returns the value of attribute actions.



43
44
45
# File 'lib/alogram_payrisk/models/decision_response.rb', line 43

def actions
  @actions
end

#assessment_idObject

Universal decision identifier. For purchases, equals paymentIntentId.



20
21
22
# File 'lib/alogram_payrisk/models/decision_response.rb', line 20

def assessment_id
  @assessment_id
end

#breakdownObject

Returns the value of attribute breakdown.



35
36
37
# File 'lib/alogram_payrisk/models/decision_response.rb', line 35

def breakdown
  @breakdown
end

#decisionObject

Returns the value of attribute decision.



22
23
24
# File 'lib/alogram_payrisk/models/decision_response.rb', line 22

def decision
  @decision
end

#decision_atObject

RFC 3339 timestamp with timezone.



25
26
27
# File 'lib/alogram_payrisk/models/decision_response.rb', line 25

def decision_at
  @decision_at
end

#decision_scoreObject

The authoritative blended risk score (0.0 - 1.0) derived from expert fusion.



31
32
33
# File 'lib/alogram_payrisk/models/decision_response.rb', line 31

def decision_score
  @decision_score
end

#fraud_scoreObject

Returns the value of attribute fraud_score.



33
34
35
# File 'lib/alogram_payrisk/models/decision_response.rb', line 33

def fraud_score
  @fraud_score
end

#model_versionObject

The version of the model that generated the decision.



52
53
54
# File 'lib/alogram_payrisk/models/decision_response.rb', line 52

def model_version
  @model_version
end

#payment_intent_idObject

Server-minted unique payment identifier.



46
47
48
# File 'lib/alogram_payrisk/models/decision_response.rb', line 46

def payment_intent_id
  @payment_intent_id
end

#policy_versionObject

The version of the policy that generated the decision.



49
50
51
# File 'lib/alogram_payrisk/models/decision_response.rb', line 49

def policy_version
  @policy_version
end

#reason_codesObject

Technical reason codes for the decision.



38
39
40
# File 'lib/alogram_payrisk/models/decision_response.rb', line 38

def reason_codes
  @reason_codes
end

#reasonsObject

Structured reason details for the decision.



41
42
43
# File 'lib/alogram_payrisk/models/decision_response.rb', line 41

def reasons
  @reasons
end

#risk_scoreObject

DEPRECATED: Use decisionScore instead. Current blended risk score.



28
29
30
# File 'lib/alogram_payrisk/models/decision_response.rb', line 28

def risk_score
  @risk_score
end

#ttl_secondsObject

Time to live for the decision in seconds.



55
56
57
# File 'lib/alogram_payrisk/models/decision_response.rb', line 55

def ttl_seconds
  @ttl_seconds
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



100
101
102
# File 'lib/alogram_payrisk/models/decision_response.rb', line 100

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



105
106
107
# File 'lib/alogram_payrisk/models/decision_response.rb', line 105

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/alogram_payrisk/models/decision_response.rb', line 80

def self.attribute_map
  {
    :'assessment_id' => :'assessmentId',
    :'decision' => :'decision',
    :'decision_at' => :'decisionAt',
    :'risk_score' => :'riskScore',
    :'decision_score' => :'decisionScore',
    :'fraud_score' => :'fraudScore',
    :'breakdown' => :'breakdown',
    :'reason_codes' => :'reasonCodes',
    :'reasons' => :'reasons',
    :'actions' => :'actions',
    :'payment_intent_id' => :'paymentIntentId',
    :'policy_version' => :'policyVersion',
    :'model_version' => :'modelVersion',
    :'ttl_seconds' => :'ttlSeconds'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/alogram_payrisk/models/decision_response.rb', line 474

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



130
131
132
133
# File 'lib/alogram_payrisk/models/decision_response.rb', line 130

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/alogram_payrisk/models/decision_response.rb', line 110

def self.openapi_types
  {
    :'assessment_id' => :'String',
    :'decision' => :'String',
    :'decision_at' => :'String',
    :'risk_score' => :'Float',
    :'decision_score' => :'Float',
    :'fraud_score' => :'FraudScore',
    :'breakdown' => :'RiskBreakdown',
    :'reason_codes' => :'Array<String>',
    :'reasons' => :'Array<ReasonDetail>',
    :'actions' => :'Array<String>',
    :'payment_intent_id' => :'String',
    :'policy_version' => :'String',
    :'model_version' => :'String',
    :'ttl_seconds' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'lib/alogram_payrisk/models/decision_response.rb', line 440

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      assessment_id == o.assessment_id &&
      decision == o.decision &&
      decision_at == o.decision_at &&
      risk_score == o.risk_score &&
      decision_score == o.decision_score &&
      fraud_score == o.fraud_score &&
      breakdown == o.breakdown &&
      reason_codes == o.reason_codes &&
      reasons == o.reasons &&
      actions == o.actions &&
      payment_intent_id == o.payment_intent_id &&
      policy_version == o.policy_version &&
      model_version == o.model_version &&
      ttl_seconds == o.ttl_seconds
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


461
462
463
# File 'lib/alogram_payrisk/models/decision_response.rb', line 461

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



467
468
469
# File 'lib/alogram_payrisk/models/decision_response.rb', line 467

def hash
  [assessment_id, decision, decision_at, risk_score, decision_score, fraud_score, breakdown, reason_codes, reasons, actions, payment_intent_id, policy_version, model_version, ttl_seconds].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/alogram_payrisk/models/decision_response.rb', line 226

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @assessment_id.nil?
    invalid_properties.push('invalid value for "assessment_id", assessment_id cannot be nil.')
  end

  if @assessment_id.to_s.length > 64
    invalid_properties.push('invalid value for "assessment_id", the character length must be smaller than or equal to 64.')
  end

  if @assessment_id.to_s.length < 8
    invalid_properties.push('invalid value for "assessment_id", the character length must be greater than or equal to 8.')
  end

  pattern = Regexp.new(/^[a-zA-Z0-9\-_]+$/)
  if @assessment_id !~ pattern
    invalid_properties.push("invalid value for \"assessment_id\", must conform to the pattern #{pattern}.")
  end

  if @decision.nil?
    invalid_properties.push('invalid value for "decision", decision cannot be nil.')
  end

  if @decision_at.nil?
    invalid_properties.push('invalid value for "decision_at", decision_at cannot be nil.')
  end

  pattern = Regexp.new(/^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(\.\d{1,9})?(Z|[+-]\d{2}:\d{2})$/)
  if @decision_at !~ pattern
    invalid_properties.push("invalid value for \"decision_at\", must conform to the pattern #{pattern}.")
  end

  if @risk_score.nil?
    invalid_properties.push('invalid value for "risk_score", risk_score cannot be nil.')
  end

  if @risk_score > 1.0
    invalid_properties.push('invalid value for "risk_score", must be smaller than or equal to 1.0.')
  end

  if @risk_score < 0.0
    invalid_properties.push('invalid value for "risk_score", must be greater than or equal to 0.0.')
  end

  if @decision_score.nil?
    invalid_properties.push('invalid value for "decision_score", decision_score cannot be nil.')
  end

  if @decision_score > 1.0
    invalid_properties.push('invalid value for "decision_score", must be smaller than or equal to 1.0.')
  end

  if @decision_score < 0.0
    invalid_properties.push('invalid value for "decision_score", must be greater than or equal to 0.0.')
  end

  if !@payment_intent_id.nil? && @payment_intent_id.to_s.length > 35
    invalid_properties.push('invalid value for "payment_intent_id", the character length must be smaller than or equal to 35.')
  end

  if !@payment_intent_id.nil? && @payment_intent_id.to_s.length < 35
    invalid_properties.push('invalid value for "payment_intent_id", the character length must be greater than or equal to 35.')
  end

  pattern = Regexp.new(/^pi_[a-f0-9]{32}$/)
  if !@payment_intent_id.nil? && @payment_intent_id !~ pattern
    invalid_properties.push("invalid value for \"payment_intent_id\", must conform to the pattern #{pattern}.")
  end

  if !@ttl_seconds.nil? && @ttl_seconds < 0
    invalid_properties.push('invalid value for "ttl_seconds", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/alogram_payrisk/models/decision_response.rb', line 496

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/alogram_payrisk/models/decision_response.rb', line 305

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @assessment_id.nil?
  return false if @assessment_id.to_s.length > 64
  return false if @assessment_id.to_s.length < 8
  return false if @assessment_id !~ Regexp.new(/^[a-zA-Z0-9\-_]+$/)
  return false if @decision.nil?
  decision_validator = EnumAttributeValidator.new('String', ["approve", "review", "decline", "step_up"])
  return false unless decision_validator.valid?(@decision)
  return false if @decision_at.nil?
  return false if @decision_at !~ Regexp.new(/^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(\.\d{1,9})?(Z|[+-]\d{2}:\d{2})$/)
  return false if @risk_score.nil?
  return false if @risk_score > 1.0
  return false if @risk_score < 0.0
  return false if @decision_score.nil?
  return false if @decision_score > 1.0
  return false if @decision_score < 0.0
  return false if !@payment_intent_id.nil? && @payment_intent_id.to_s.length > 35
  return false if !@payment_intent_id.nil? && @payment_intent_id.to_s.length < 35
  return false if !@payment_intent_id.nil? && @payment_intent_id !~ Regexp.new(/^pi_[a-f0-9]{32}$/)
  return false if !@ttl_seconds.nil? && @ttl_seconds < 0
  true
end