Class: AlogramPayRisk::KycPayload
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- AlogramPayRisk::KycPayload
- Defined in:
- lib/alogram_payrisk/models/kyc_payload.rb
Overview
KYC provider result payload.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#country ⇒ Object
Returns the value of attribute country.
-
#document_type ⇒ Object
The document type used for verification.
-
#metadata ⇒ Object
Optional key-value pairs providing additional context for the request.
-
#provider ⇒ Object
Returns the value of attribute provider.
-
#reason_codes ⇒ Object
Array of reason codes for the KYC check.
-
#result ⇒ Object
The result of the KYC check.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ KycPayload
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ KycPayload
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::KycPayload` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::KycPayload`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'provider') self.provider = attributes[:'provider'] end if attributes.key?(:'document_type') self.document_type = attributes[:'document_type'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'result') self.result = attributes[:'result'] end if attributes.key?(:'reason_codes') if (value = attributes[:'reason_codes']).is_a?(Array) self.reason_codes = value end end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end end |
Instance Attribute Details
#country ⇒ Object
Returns the value of attribute country.
24 25 26 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 24 def country @country end |
#document_type ⇒ Object
The document type used for verification.
22 23 24 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 22 def document_type @document_type end |
#metadata ⇒ Object
Optional key-value pairs providing additional context for the request. Each key should be descriptive, and values should not exceed 2048 characters. Each key should be descriptive.
33 34 35 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 33 def @metadata end |
#provider ⇒ Object
Returns the value of attribute provider.
19 20 21 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 19 def provider @provider end |
#reason_codes ⇒ Object
Array of reason codes for the KYC check.
30 31 32 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 30 def reason_codes @reason_codes end |
#result ⇒ Object
The result of the KYC check.
27 28 29 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 27 def result @result end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 58 def self.attribute_map { :'provider' => :'provider', :'document_type' => :'documentType', :'country' => :'country', :'result' => :'result', :'reason_codes' => :'reasonCodes', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 255 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 92 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 80 def self.openapi_types { :'provider' => :'String', :'document_type' => :'String', :'country' => :'String', :'result' => :'String', :'reason_codes' => :'Array<String>', :'metadata' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
229 230 231 232 233 234 235 236 237 238 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 229 def ==(o) return true if self.equal?(o) self.class == o.class && provider == o.provider && document_type == o.document_type && country == o.country && result == o.result && reason_codes == o.reason_codes && == o. end |
#eql?(o) ⇒ Boolean
242 243 244 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 242 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 248 def hash [provider, document_type, country, result, reason_codes, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 142 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@country.nil? && @country.to_s.length > 2 invalid_properties.push('invalid value for "country", the character length must be smaller than or equal to 2.') end if !@country.nil? && @country.to_s.length < 2 invalid_properties.push('invalid value for "country", the character length must be greater than or equal to 2.') end if !@metadata.nil? && @metadata.to_s.length > 2048 invalid_properties.push('invalid value for "metadata", the character length must be smaller than or equal to 2048.') end if !@metadata.nil? && @metadata.to_s.length < 1 invalid_properties.push('invalid value for "metadata", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 277 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/alogram_payrisk/models/kyc_payload.rb', line 166 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' document_type_validator = EnumAttributeValidator.new('String', ["passport", "national_id", "driver_license", "other"]) return false unless document_type_validator.valid?(@document_type) return false if !@country.nil? && @country.to_s.length > 2 return false if !@country.nil? && @country.to_s.length < 2 result_validator = EnumAttributeValidator.new('String', ["passed", "failed", "review", "timeout", "error"]) return false unless result_validator.valid?(@result) return false if !@metadata.nil? && @metadata.to_s.length > 2048 return false if !@metadata.nil? && @metadata.to_s.length < 1 true end |