Class: AlogramPayRisk::PostalAddress
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- AlogramPayRisk::PostalAddress
- Defined in:
- lib/alogram_payrisk/models/postal_address.rb
Overview
Postal address used for shipping or billing. Raw values are used only for normalization and risk signals; Alogram will not persist raw address fields in long-term storage.
Instance Attribute Summary collapse
-
#city ⇒ Object
City or locality.
-
#country ⇒ Object
ISO 3166-1 alpha-2 country code.
-
#line1 ⇒ Object
First line of the street address.
-
#line2 ⇒ Object
Second line of the street address (apartment, suite, etc.).
-
#postal_code ⇒ Object
Postal / ZIP code.
-
#region ⇒ Object
State, province, or region.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PostalAddress
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PostalAddress
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::PostalAddress` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::PostalAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'line1') self.line1 = attributes[:'line1'] end if attributes.key?(:'line2') self.line2 = attributes[:'line2'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'region') self.region = attributes[:'region'] end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] end if attributes.key?(:'country') self.country = attributes[:'country'] end end |
Instance Attribute Details
#city ⇒ Object
City or locality.
26 27 28 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 26 def city @city end |
#country ⇒ Object
ISO 3166-1 alpha-2 country code.
35 36 37 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 35 def country @country end |
#line1 ⇒ Object
First line of the street address.
20 21 22 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 20 def line1 @line1 end |
#line2 ⇒ Object
Second line of the street address (apartment, suite, etc.).
23 24 25 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 23 def line2 @line2 end |
#postal_code ⇒ Object
Postal / ZIP code.
32 33 34 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 32 def postal_code @postal_code end |
#region ⇒ Object
State, province, or region.
29 30 31 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 29 def region @region end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 38 def self.attribute_map { :'line1' => :'line1', :'line2' => :'line2', :'city' => :'city', :'region' => :'region', :'postal_code' => :'postalCode', :'country' => :'country' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 295 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 60 def self.openapi_types { :'line1' => :'String', :'line2' => :'String', :'city' => :'String', :'region' => :'String', :'postal_code' => :'String', :'country' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
269 270 271 272 273 274 275 276 277 278 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 269 def ==(o) return true if self.equal?(o) self.class == o.class && line1 == o.line1 && line2 == o.line2 && city == o.city && region == o.region && postal_code == o.postal_code && country == o.country end |
#eql?(o) ⇒ Boolean
282 283 284 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 282 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
288 289 290 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 288 def hash [line1, line2, city, region, postal_code, country].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@line1.nil? && @line1.to_s.length > 128 invalid_properties.push('invalid value for "line1", the character length must be smaller than or equal to 128.') end if !@line2.nil? && @line2.to_s.length > 128 invalid_properties.push('invalid value for "line2", the character length must be smaller than or equal to 128.') end if !@city.nil? && @city.to_s.length > 60 invalid_properties.push('invalid value for "city", the character length must be smaller than or equal to 60.') end if !@region.nil? && @region.to_s.length > 60 invalid_properties.push('invalid value for "region", the character length must be smaller than or equal to 60.') end if !@postal_code.nil? && @postal_code.to_s.length > 20 invalid_properties.push('invalid value for "postal_code", the character length must be smaller than or equal to 20.') end if !@country.nil? && @country.to_s.length > 2 invalid_properties.push('invalid value for "country", the character length must be smaller than or equal to 2.') end if !@country.nil? && @country.to_s.length < 2 invalid_properties.push('invalid value for "country", the character length must be greater than or equal to 2.') end pattern = Regexp.new(/^[A-Z]{2}$/) if !@country.nil? && @country !~ pattern invalid_properties.push("invalid value for \"country\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 317 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/alogram_payrisk/models/postal_address.rb', line 161 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@line1.nil? && @line1.to_s.length > 128 return false if !@line2.nil? && @line2.to_s.length > 128 return false if !@city.nil? && @city.to_s.length > 60 return false if !@region.nil? && @region.to_s.length > 60 return false if !@postal_code.nil? && @postal_code.to_s.length > 20 return false if !@country.nil? && @country.to_s.length > 2 return false if !@country.nil? && @country.to_s.length < 2 return false if !@country.nil? && @country !~ Regexp.new(/^[A-Z]{2}$/) true end |