Class: AlogramPayRisk::Problem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- AlogramPayRisk::Problem
- Defined in:
- lib/alogram_payrisk/models/problem.rb
Overview
RFC 7807 Problem Details
Instance Attribute Summary collapse
-
#detail ⇒ Object
Human-readable explanation specific to this occurrence.
-
#error_code ⇒ Object
Application-specific error code.
-
#instance ⇒ Object
A URI reference that identifies the specific occurrence.
-
#status ⇒ Object
The HTTP status code applicable to this problem.
-
#title ⇒ Object
A short, human-readable summary of the problem type.
-
#trace_id ⇒ Object
Server-generated trace ID for debugging.
-
#type ⇒ Object
A URI reference that identifies the problem type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Problem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Problem
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/alogram_payrisk/models/problem.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::Problem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::Problem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = 'about:blank' end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'detail') self.detail = attributes[:'detail'] end if attributes.key?(:'instance') self.instance = attributes[:'instance'] end if attributes.key?(:'error_code') self.error_code = attributes[:'error_code'] end if attributes.key?(:'trace_id') self.trace_id = attributes[:'trace_id'] end end |
Instance Attribute Details
#detail ⇒ Object
Human-readable explanation specific to this occurrence.
29 30 31 |
# File 'lib/alogram_payrisk/models/problem.rb', line 29 def detail @detail end |
#error_code ⇒ Object
Application-specific error code.
35 36 37 |
# File 'lib/alogram_payrisk/models/problem.rb', line 35 def error_code @error_code end |
#instance ⇒ Object
A URI reference that identifies the specific occurrence.
32 33 34 |
# File 'lib/alogram_payrisk/models/problem.rb', line 32 def instance @instance end |
#status ⇒ Object
The HTTP status code applicable to this problem.
26 27 28 |
# File 'lib/alogram_payrisk/models/problem.rb', line 26 def status @status end |
#title ⇒ Object
A short, human-readable summary of the problem type.
23 24 25 |
# File 'lib/alogram_payrisk/models/problem.rb', line 23 def title @title end |
#trace_id ⇒ Object
Server-generated trace ID for debugging.
38 39 40 |
# File 'lib/alogram_payrisk/models/problem.rb', line 38 def trace_id @trace_id end |
#type ⇒ Object
A URI reference that identifies the problem type.
20 21 22 |
# File 'lib/alogram_payrisk/models/problem.rb', line 20 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/alogram_payrisk/models/problem.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/alogram_payrisk/models/problem.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/alogram_payrisk/models/problem.rb', line 41 def self.attribute_map { :'type' => :'type', :'title' => :'title', :'status' => :'status', :'detail' => :'detail', :'instance' => :'instance', :'error_code' => :'errorCode', :'trace_id' => :'traceId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/alogram_payrisk/models/problem.rb', line 293 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/alogram_payrisk/models/problem.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/alogram_payrisk/models/problem.rb', line 64 def self.openapi_types { :'type' => :'String', :'title' => :'String', :'status' => :'Integer', :'detail' => :'String', :'instance' => :'String', :'error_code' => :'String', :'trace_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/alogram_payrisk/models/problem.rb', line 266 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && title == o.title && status == o.status && detail == o.detail && instance == o.instance && error_code == o.error_code && trace_id == o.trace_id end |
#eql?(o) ⇒ Boolean
280 281 282 |
# File 'lib/alogram_payrisk/models/problem.rb', line 280 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
286 287 288 |
# File 'lib/alogram_payrisk/models/problem.rb', line 286 def hash [type, title, status, detail, instance, error_code, trace_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/alogram_payrisk/models/problem.rb', line 131 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@title.nil? && @title.to_s.length > 100 invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 100.') end if !@title.nil? && @title.to_s.length < 3 invalid_properties.push('invalid value for "title", the character length must be greater than or equal to 3.') end if !@status.nil? && @status > 599 invalid_properties.push('invalid value for "status", must be smaller than or equal to 599.') end if !@status.nil? && @status < 100 invalid_properties.push('invalid value for "status", must be greater than or equal to 100.') end if !@detail.nil? && @detail.to_s.length > 1024 invalid_properties.push('invalid value for "detail", the character length must be smaller than or equal to 1024.') end if !@detail.nil? && @detail.to_s.length < 3 invalid_properties.push('invalid value for "detail", the character length must be greater than or equal to 3.') end if !@instance.nil? && @instance.to_s.length > 1024 invalid_properties.push('invalid value for "instance", the character length must be smaller than or equal to 1024.') end if !@instance.nil? && @instance.to_s.length < 1 invalid_properties.push('invalid value for "instance", the character length must be greater than or equal to 1.') end if !@error_code.nil? && @error_code.to_s.length > 50 invalid_properties.push('invalid value for "error_code", the character length must be smaller than or equal to 50.') end if !@error_code.nil? && @error_code.to_s.length < 3 invalid_properties.push('invalid value for "error_code", the character length must be greater than or equal to 3.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/alogram_payrisk/models/problem.rb', line 315 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/alogram_payrisk/models/problem.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@title.nil? && @title.to_s.length > 100 return false if !@title.nil? && @title.to_s.length < 3 return false if !@status.nil? && @status > 599 return false if !@status.nil? && @status < 100 return false if !@detail.nil? && @detail.to_s.length > 1024 return false if !@detail.nil? && @detail.to_s.length < 3 return false if !@instance.nil? && @instance.to_s.length > 1024 return false if !@instance.nil? && @instance.to_s.length < 1 return false if !@error_code.nil? && @error_code.to_s.length > 50 return false if !@error_code.nil? && @error_code.to_s.length < 3 true end |