Class: AlogramPayRisk::ScoreRecord
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- AlogramPayRisk::ScoreRecord
- Defined in:
- lib/alogram_payrisk/models/score_record.rb
Overview
Fraud score for a specific transaction or entity.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
Value of the purchase in the specified currency.
-
#assessment_id ⇒ Object
Universal decision identifier (for purchases, equals paymentIntentId).
-
#breakdown ⇒ Object
Returns the value of attribute breakdown.
-
#currency ⇒ Object
ISO 4217 currency code (e.g., ‘USD’).
-
#decision ⇒ Object
The synchronous risk decision for a purchase.
-
#decision_at ⇒ Object
RFC 3339 timestamp with timezone.
-
#decision_score ⇒ Object
The authoritative blended risk score (0.0 - 1.0) derived from expert fusion.
-
#entities ⇒ Object
Returns the value of attribute entities.
-
#fraud_score ⇒ Object
Returns the value of attribute fraud_score.
-
#payment_intent_id ⇒ Object
Server-minted unique payment identifier.
-
#reasons ⇒ Object
Structured reason details for the score.
-
#risk_score ⇒ Object
DEPRECATED: Use decisionScore instead.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ScoreRecord
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ScoreRecord
Initializes the object
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 128 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AlogramPayRisk::ScoreRecord` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AlogramPayRisk::ScoreRecord`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'assessment_id') self.assessment_id = attributes[:'assessment_id'] else self.assessment_id = nil end if attributes.key?(:'payment_intent_id') self.payment_intent_id = attributes[:'payment_intent_id'] end if attributes.key?(:'decision_at') self.decision_at = attributes[:'decision_at'] else self.decision_at = nil end if attributes.key?(:'decision') self.decision = attributes[:'decision'] else self.decision = nil end if attributes.key?(:'risk_score') self.risk_score = attributes[:'risk_score'] else self.risk_score = nil end if attributes.key?(:'decision_score') self.decision_score = attributes[:'decision_score'] else self.decision_score = nil end if attributes.key?(:'fraud_score') self.fraud_score = attributes[:'fraud_score'] end if attributes.key?(:'breakdown') self.breakdown = attributes[:'breakdown'] end if attributes.key?(:'reasons') if (value = attributes[:'reasons']).is_a?(Array) self.reasons = value end end if attributes.key?(:'entities') self.entities = attributes[:'entities'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end end |
Instance Attribute Details
#amount ⇒ Object
Value of the purchase in the specified currency. Must be a positive number with up to two decimal places.
47 48 49 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 47 def amount @amount end |
#assessment_id ⇒ Object
Universal decision identifier (for purchases, equals paymentIntentId).
20 21 22 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 20 def assessment_id @assessment_id end |
#breakdown ⇒ Object
Returns the value of attribute breakdown.
39 40 41 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 39 def breakdown @breakdown end |
#currency ⇒ Object
ISO 4217 currency code (e.g., ‘USD’).
50 51 52 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 50 def currency @currency end |
#decision ⇒ Object
The synchronous risk decision for a purchase.
29 30 31 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 29 def decision @decision end |
#decision_at ⇒ Object
RFC 3339 timestamp with timezone.
26 27 28 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 26 def decision_at @decision_at end |
#decision_score ⇒ Object
The authoritative blended risk score (0.0 - 1.0) derived from expert fusion.
35 36 37 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 35 def decision_score @decision_score end |
#entities ⇒ Object
Returns the value of attribute entities.
44 45 46 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 44 def entities @entities end |
#fraud_score ⇒ Object
Returns the value of attribute fraud_score.
37 38 39 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 37 def fraud_score @fraud_score end |
#payment_intent_id ⇒ Object
Server-minted unique payment identifier.
23 24 25 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 23 def payment_intent_id @payment_intent_id end |
#reasons ⇒ Object
Structured reason details for the score.
42 43 44 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 42 def reasons @reasons end |
#risk_score ⇒ Object
DEPRECATED: Use decisionScore instead. Fraud risk score (0.00 - 1.00).
32 33 34 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 32 def risk_score @risk_score end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
93 94 95 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 93 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
98 99 100 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 98 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 75 def self.attribute_map { :'assessment_id' => :'assessmentId', :'payment_intent_id' => :'paymentIntentId', :'decision_at' => :'decisionAt', :'decision' => :'decision', :'risk_score' => :'riskScore', :'decision_score' => :'decisionScore', :'fraud_score' => :'fraudScore', :'breakdown' => :'breakdown', :'reasons' => :'reasons', :'entities' => :'entities', :'amount' => :'amount', :'currency' => :'currency' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 467 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
121 122 123 124 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 121 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 103 def self.openapi_types { :'assessment_id' => :'String', :'payment_intent_id' => :'String', :'decision_at' => :'String', :'decision' => :'String', :'risk_score' => :'Float', :'decision_score' => :'Float', :'fraud_score' => :'FraudScore', :'breakdown' => :'RiskBreakdown', :'reasons' => :'Array<ReasonDetail>', :'entities' => :'EntityIds', :'amount' => :'Float', :'currency' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 435 def ==(o) return true if self.equal?(o) self.class == o.class && assessment_id == o.assessment_id && payment_intent_id == o.payment_intent_id && decision_at == o.decision_at && decision == o.decision && risk_score == o.risk_score && decision_score == o.decision_score && fraud_score == o.fraud_score && breakdown == o.breakdown && reasons == o.reasons && entities == o.entities && amount == o.amount && currency == o.currency end |
#eql?(o) ⇒ Boolean
454 455 456 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 454 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
460 461 462 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 460 def hash [assessment_id, payment_intent_id, decision_at, decision, risk_score, decision_score, fraud_score, breakdown, reasons, entities, amount, currency].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 205 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @assessment_id.nil? invalid_properties.push('invalid value for "assessment_id", assessment_id cannot be nil.') end if !@payment_intent_id.nil? && @payment_intent_id.to_s.length > 35 invalid_properties.push('invalid value for "payment_intent_id", the character length must be smaller than or equal to 35.') end if !@payment_intent_id.nil? && @payment_intent_id.to_s.length < 35 invalid_properties.push('invalid value for "payment_intent_id", the character length must be greater than or equal to 35.') end pattern = Regexp.new(/^pi_[a-f0-9]{32}$/) if !@payment_intent_id.nil? && @payment_intent_id !~ pattern invalid_properties.push("invalid value for \"payment_intent_id\", must conform to the pattern #{pattern}.") end if @decision_at.nil? invalid_properties.push('invalid value for "decision_at", decision_at cannot be nil.') end pattern = Regexp.new(/^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(\.\d{1,9})?(Z|[+-]\d{2}:\d{2})$/) if @decision_at !~ pattern invalid_properties.push("invalid value for \"decision_at\", must conform to the pattern #{pattern}.") end if @decision.nil? invalid_properties.push('invalid value for "decision", decision cannot be nil.') end if @risk_score.nil? invalid_properties.push('invalid value for "risk_score", risk_score cannot be nil.') end if @risk_score > 1.0 invalid_properties.push('invalid value for "risk_score", must be smaller than or equal to 1.0.') end if @risk_score < 0.0 invalid_properties.push('invalid value for "risk_score", must be greater than or equal to 0.0.') end if @decision_score.nil? invalid_properties.push('invalid value for "decision_score", decision_score cannot be nil.') end if @decision_score > 1.0 invalid_properties.push('invalid value for "decision_score", must be smaller than or equal to 1.0.') end if @decision_score < 0.0 invalid_properties.push('invalid value for "decision_score", must be greater than or equal to 0.0.') end if !@amount.nil? && @amount > 1.0E+7 invalid_properties.push('invalid value for "amount", must be smaller than or equal to 1.0E+7.') end if !@amount.nil? && @amount < 0.01 invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.01.') end if !@currency.nil? && @currency.to_s.length > 3 invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.') end if !@currency.nil? && @currency.to_s.length < 3 invalid_properties.push('invalid value for "currency", the character length must be greater than or equal to 3.') end pattern = Regexp.new(/^[A-Z]{3}$/) if !@currency.nil? && @currency !~ pattern invalid_properties.push("invalid value for \"currency\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 489 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/alogram_payrisk/models/score_record.rb', line 288 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @assessment_id.nil? return false if !@payment_intent_id.nil? && @payment_intent_id.to_s.length > 35 return false if !@payment_intent_id.nil? && @payment_intent_id.to_s.length < 35 return false if !@payment_intent_id.nil? && @payment_intent_id !~ Regexp.new(/^pi_[a-f0-9]{32}$/) return false if @decision_at.nil? return false if @decision_at !~ Regexp.new(/^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(\.\d{1,9})?(Z|[+-]\d{2}:\d{2})$/) return false if @decision.nil? decision_validator = EnumAttributeValidator.new('String', ["approve", "review", "decline", "step_up"]) return false unless decision_validator.valid?(@decision) return false if @risk_score.nil? return false if @risk_score > 1.0 return false if @risk_score < 0.0 return false if @decision_score.nil? return false if @decision_score > 1.0 return false if @decision_score < 0.0 return false if !@amount.nil? && @amount > 1.0E+7 return false if !@amount.nil? && @amount < 0.01 return false if !@currency.nil? && @currency.to_s.length > 3 return false if !@currency.nil? && @currency.to_s.length < 3 return false if !@currency.nil? && @currency !~ Regexp.new(/^[A-Z]{3}$/) true end |